@@ -5,13 +5,13 @@
  *
  *      Description:  A flexible and extensible benchmarking toolbox
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:  Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -40,6 +40,7 @@
 #include <inttypes.h>
 #include <math.h>
 #include <signal.h>
+#include <getopt.h>
 
 #include <bstrlib.h>
 #include <errno.h>
@@ -61,25 +62,26 @@ extern void* getIterSingle(void* arg);
 
 /* #####   MACROS  -  LOCAL TO THIS SOURCE FILE   ######################### */
 
-#define HELP_MSG printf("Threaded Memory Hierarchy Benchmark --  Version  %d.%d \n\n",VERSION,RELEASE); \
+#define HELP_MSG printf("Threaded Memory Hierarchy Benchmark -- Version %d.%d.%d \n\n",VERSION,RELEASE,MINORVERSION); \
     printf("\n"); \
     printf("Supported Options:\n"); \
-    printf("-h\t\t Help message\n"); \
-    printf("-a\t\t List available benchmarks \n"); \
-    printf("-d\t\t Delimiter used for physical hwthread list (default ,) \n"); \
-    printf("-p\t\t List available thread domains\n"); \
-    printf("\t\t or the physical ids of the hwthreads selected by the -c expression \n"); \
-    printf("-s <TIME>\t Seconds to run the test minimally (default 1)\n");\
-    printf("\t\t If resulting iteration count is below 10, it is normalized to 10.\n");\
-    printf("-i <ITERS>\t Specify the number of iterations per thread manually. \n"); \
-    printf("-l <TEST>\t list properties of benchmark \n"); \
-    printf("-t <TEST>\t type of test \n"); \
-    printf("-w\t\t <thread_domain>:<size>[:<num_threads>[:<chunk size>:<stride>]-<streamId>:<domain_id>[:<offset>]\n"); \
-    printf("-W\t\t <thread_domain>:<size>[:<num_threads>[:<chunk size>:<stride>]]\n"); \
-    printf("\t\t <size> in kB, MB or GB (mandatory)\n"); \
+    printf("-h/--help\t\t Help message\n"); \
+    printf("-v/--version\t\t Version\n"); \
+    printf("-a/--all\t\t List available benchmarks \n"); \
+    printf("-d/--delim\t\t Delimiter used for physical hwthread list (default ,) \n"); \
+    printf("-p/--printdomains\t List available thread domains\n"); \
+    printf("\t\t\t\t or the physical ids of the hwthreads selected by the -c expression \n"); \
+    printf("-s/--runtime <TIME>\t Seconds to run the test minimally (default 1)\n");\
+    printf("\t\t\t\t If resulting iteration count is below 10, it is normalized to 10.\n");\
+    printf("-i/--iters <ITERS>\t Specify the number of iterations per thread manually. \n"); \
+    printf("-l/--list <TEST>\t list properties of benchmark \n"); \
+    printf("-t/--test <TEST>\t type of test \n"); \
+    printf("-w/--workgroup\t\t <thread_domain>:<size>[:<num_threads>[:<chunk size>:<stride>]-<streamId>:<domain_id>[:<offset>]\n"); \
+    printf("-W/--Workgroup\t\t <thread_domain>:<size>[:<num_threads>[:<chunk size>:<stride>]]\n"); \
+    printf("\t\t\t\t <size> in B, kB, MB, GB, kiB, MiB or GiB (mandatory)\n"); \
     printf("For dynamically loaded benchmarks\n"); \
-    printf("-f <PATH>\t Specify a folder for the temporary files. default: /tmp\n"); \
-    printf("-o <FILE>\t Save generated assembly to file\n"); \
+    printf("-f/--tempdir <PATH>\t Specify a folder for the temporary files. default: /tmp\n"); \
+    printf("-o/--asmout <FILE>\t Save generated assembly to file\n"); \
     printf("\n"); \
     printf("Difference between -w and -W :\n"); \
     printf("-w allocates the streams in the thread_domain with one thread and support placement of streams\n"); \
@@ -97,6 +99,24 @@ extern void* getIterSingle(void* arg);
 
 #define VERSION_MSG \
     printf("likwid-bench -- Version %d.%d.%d\n",VERSION,RELEASE,MINORVERSION); \
+    
+static struct option bench_cli_options[] =
+{
+    {"help", no_argument, NULL, 'h'},
+    {"all", no_argument, NULL, 'a'},
+    {"version", no_argument, NULL, 'v'},
+    {"delim", required_argument, NULL, 'd'},
+    {"printdomains", no_argument, NULL, 'p'},
+    {"runtime", required_argument, NULL, 's'},
+    {"iters", required_argument, NULL, 'i'},
+    {"list", required_argument, NULL, 'l'},
+    {"test", required_argument, NULL, 't'},
+    {"workgroup", required_argument, NULL, 'w'},
+    {"Workgroup", required_argument, NULL, 'W'},
+    {"tempdir", required_argument, NULL, 'f'},
+    {"asmout", required_argument, NULL, 'o'},
+    {NULL, 0, NULL, 0}
+};
 
 /* #####   FUNCTION DEFINITIONS  -  LOCAL TO THIS SOURCE FILE  ############ */
 
@@ -123,6 +143,9 @@ copyThreadData(ThreadUserData* src,ThreadUserData* dst)
 
 void illhandler(int signum, siginfo_t *info, void *ptr)
 {
+    (void)signum;
+    (void)info;
+    (void)ptr;
     fprintf(stderr, "ERROR: Illegal instruction\n");
     fprintf(stderr, "This happens if you want to run a kernel that uses instructions not available on your system.\n");
     exit(EXIT_FAILURE);
@@ -134,7 +157,6 @@ void illhandler(int signum, siginfo_t *info, void *ptr)
 int main(int argc, char** argv)
 {
     uint64_t iter = 100;
-    uint32_t i;
     uint32_t j;
     int globalNumberOfThreads = 0;
     int optPrintDomains = 0;
@@ -146,7 +168,6 @@ int main(int argc, char** argv)
     uint64_t numberOfWorkgroups = 0;
     int tmp = 0;
     double time;
-    double cycPerUp = 0.0;
     double cycPerCL = 0.0;
     TestCase* test = NULL;
     uint64_t realSize = 0;
@@ -182,7 +203,7 @@ int main(int argc, char** argv)
         exit(EXIT_SUCCESS);
     }
 
-    while ((c = getopt (argc, argv, "W:w:t:s:l:aphvi:f:o:")) != -1) {
+    while ((c = getopt_long (argc, argv, "W:w:t:s:l:aphvi:f:o:", bench_cli_options, NULL)) != -1) {
         switch (c)
         {
             case 'f':
@@ -203,7 +224,7 @@ int main(int argc, char** argv)
     }
     optind = 0;
 
-    while ((c = getopt (argc, argv, "W:w:t:s:l:aphvi:f:o:")) != -1) {
+    while ((c = getopt_long (argc, argv, "W:w:t:s:l:aphvi:f:o:", bench_cli_options, NULL)) != -1) {
         switch (c)
         {
             case 'h':
@@ -219,7 +240,7 @@ int main(int argc, char** argv)
                 if (l)
                 {
                     ownprintf("\nUser benchmarks:\n");
-                    for (i = 0; i < l->qty; i++)
+                    for (int i = 0; i < l->qty; i++)
                     {
                         if (dynbench_test(l->entry[i]))
                         {
@@ -254,7 +275,7 @@ int main(int argc, char** argv)
                 bdestroy(testcase);
                 testcase = bfromcstr(optarg);
                 int builtin = 1;
-                for (i=0; i<NUMKERNELS; i++)
+                for (uint32_t i=0; i<NUMKERNELS; i++)
                 {
                     if (biseqcstr(testcase, kernels[i].name))
                     {
@@ -335,6 +356,7 @@ int main(int argc, char** argv)
                     }
                 }
                 bdestroy(testcase);
+                testcase = bfromcstr("none");
                 if (!builtin)
                 {
                     dynbench_close(test, NULL);
@@ -355,7 +377,7 @@ int main(int argc, char** argv)
                 bdestroy(testcase);
                 testcase = bfromcstr(optarg);
 
-                for (i=0; i<NUMKERNELS; i++)
+                for (uint32_t i=0; i<NUMKERNELS; i++)
                 {
                     if (biseqcstr(testcase, kernels[i].name))
                     {
@@ -390,6 +412,7 @@ int main(int argc, char** argv)
                     return EXIT_FAILURE;
                 }
                 bdestroy(testcase);
+                testcase = bfromcstr("none");
                 break;
             case 'o':
             case 'f':
@@ -439,7 +462,7 @@ int main(int argc, char** argv)
         bdestroy(testcase);
         AffinityDomains_t affinity = get_affinityDomains();
         ownprintf("Number of Domains %d\n",affinity->numberOfAffinityDomains);
-        for (i=0; i < affinity->numberOfAffinityDomains; i++ )
+        for (uint32_t i=0; i < affinity->numberOfAffinityDomains; i++ )
         {
             ownprintf("Domain %d:\n",i);
             ownprintf("\tTag %s:",affinity->domains[i].tag);
@@ -471,21 +494,20 @@ int main(int argc, char** argv)
                 {
                     currentWorkgroup->init_per_thread = 1;
                 }
-                i = bstr_to_workgroup(currentWorkgroup, groupstr, test->type, test->streams);
+                int unknown = bstr_to_workgroup(currentWorkgroup, groupstr, test->type, test->streams);
                 bdestroy(groupstr);
                 size_t newsize = 0;
                 size_t stride = test->stride;
-                int nrThreads = currentWorkgroup->numberOfThreads;
-                int clsize = 128;
+                uint32_t nrThreads = currentWorkgroup->numberOfThreads;
                 size_t orig_size = currentWorkgroup->size;
-                if (i == 0)
+                if (unknown == 0)
                 {
                     int warn_once = 1;
-                    for (i=0; i<  test->streams; i++)
+                    for (size_t i=0; i<  test->streams; i++)
                     {
                         if (currentWorkgroup->streams[i].offset%test->stride)
                         {
-                            fprintf (stderr, "Error: Stream %d: offset is not a multiple of stride!\n",i);
+                            fprintf (stderr, "Error: Stream %zu: offset is not a multiple of stride!\n",i);
                             return EXIT_FAILURE;
                         }
                         if ((int)(floor(orig_size/currentWorkgroup->numberOfThreads)) % test->stride)
@@ -494,20 +516,20 @@ int main(int argc, char** argv)
                             newsize = (((size_t)(floor(orig_size/nrThreads))/stride)*(stride))*nrThreads;
                             if (newsize > 0 && warn_once)
                             {
-                                fprintf (stdout, "Warning: Sanitizing vector length to a multiple of the loop stride %d and thread count %d from %ld elements (%ld bytes) to %ld elements (%ld bytes)\n",stride, nrThreads, orig_size, orig_size*typesize, newsize, newsize*typesize);
+                                fprintf (stdout, "Warning: Sanitizing vector length to a multiple of the loop stride %zu and thread count %u from %ld elements (%ld bytes) to %ld elements (%ld bytes)\n",stride, nrThreads, orig_size, orig_size*typesize, newsize, newsize*typesize);
                                 warn_once = 0;
                             }
                             else if (newsize == 0)
                             {
                                 int given = currentWorkgroup->size*test->streams*typesize;
-                                int each_iter = test->stride*test->bytes;
+                                size_t each_iter = test->stride*test->bytes;
                                 // For the case that one stream is used for loading and storing
                                 // Cases are daxpy and update
                                 if (test->streams*typesize*test->stride < each_iter)
                                 {
                                     each_iter = test->streams*typesize*test->stride;
                                 }
-                                fprintf(stderr, "Error: The given vector length of %dB is too small to fit %d threads because each loop iteration of kernel '%s' requires %d Bytes (%d x %dB = %dB). So the minimal selectable size for the kernel is %dB.\n", given, nrThreads, test->name, each_iter, nrThreads, each_iter, each_iter*nrThreads, each_iter*nrThreads);
+                                fprintf(stderr, "Error: The given vector length of %dB is too small to fit %u threads because each loop iteration of kernel '%s' requires %zu Bytes (%d x %zuB = %zuB). So the minimal selectable size for the kernel is %zuB.\n", given, nrThreads, test->name, each_iter, nrThreads, each_iter, each_iter*nrThreads, each_iter*nrThreads);
                                 allocator_finalize();
                                 workgroups_destroy(&groups, numberOfWorkgroups, test->streams);
                                 exit(EXIT_FAILURE);
@@ -555,9 +577,9 @@ int main(int argc, char** argv)
     }
     if (numberOfWorkgroups > 1)
     {
-        int g0_numberOfThreads = groups[0].numberOfThreads;
-        int g0_size = groups[0].size;
-        for (i = 1; i < numberOfWorkgroups; i++)
+        const uint32_t g0_numberOfThreads = groups[0].numberOfThreads;
+        const uint64_t g0_size = groups[0].size;
+        for (uint64_t i = 1; i < numberOfWorkgroups; i++)
         {
             if (g0_numberOfThreads != groups[i].numberOfThreads)
             {
@@ -565,7 +587,7 @@ int main(int argc, char** argv)
                 break;
             }
         }
-        for (i = 1; i < numberOfWorkgroups; i++)
+        for (uint64_t i = 1; i < numberOfWorkgroups; i++)
         {
             if (g0_size != groups[i].size)
             {
@@ -575,7 +597,7 @@ int main(int argc, char** argv)
         }
     }
 
-    for (i=0; i<numberOfWorkgroups; i++)
+    for (uint64_t i=0; i<numberOfWorkgroups; i++)
     {
         globalNumberOfThreads += groups[i].numberOfThreads;
     }
@@ -608,7 +630,7 @@ int main(int argc, char** argv)
 
 
     /* initialize data structures for threads */
-    for (i=0; i<numberOfWorkgroups; i++)
+    for (uint64_t i=0; i<numberOfWorkgroups; i++)
     {
         myData.iter = iter;
         if (demandIter > 0)
@@ -643,7 +665,7 @@ int main(int argc, char** argv)
     if (demandIter == 0)
     {
         getIterSingle((void*) &threads_data[0]);
-        for (i=0; i<numberOfWorkgroups; i++)
+        for (uint64_t i=0; i<numberOfWorkgroups; i++)
         {
             iter = threads_updateIterations(i, demandIter);
         }
@@ -699,7 +721,6 @@ int main(int argc, char** argv)
     uint64_t size_per_thread = threads_data[0].data.size;
     uint64_t iters_per_thread = threads_data[0].data.iter;
     uint64_t datavol = iters_per_thread * realSize * test->bytes;
-    uint64_t allIters = realIter * (int)(((double)realSize)/((double)test->stride*globalNumberOfThreads));
     ownprintf(bdata(HLINE));
     ownprintf("Cycles:\t\t\t%" PRIu64 "\n", maxCycles);
     ownprintf("CPU Clock:\t\t%" PRIu64 "\n", timer_getCpuClock());
@@ -718,24 +739,20 @@ int main(int argc, char** argv)
     ownprintf("MByte/s:\t\t%.2f\n",
             1.0E-06 * ( (double) (iters_per_thread * realSize * test->bytes) / time));
 
-    size_t destsize = 0;
     size_t datasize = 0;
     double perUpFactor = 0.0;
     switch (test->type)
     {
         case INT:
             datasize = test->bytes/sizeof(int);
-            destsize = test->bytes/test->streams;
             perUpFactor = (clsize/sizeof(int));
             break;
         case SINGLE:
             datasize = test->bytes/sizeof(float);
-            destsize = test->bytes/test->streams;
             perUpFactor = (clsize/sizeof(float));
             break;
         case DOUBLE:
             datasize = test->bytes/sizeof(double);
-            destsize = test->bytes/test->streams;
             perUpFactor = (clsize/sizeof(double));
             break;
     }
@@ -797,5 +814,6 @@ int main(int argc, char** argv)
 
     bdestroy(HLINE);
     bdestroy(asmFile);
+    bdestroy(testcase);
     return EXIT_SUCCESS;
 }
