@@ -5,13 +5,13 @@
  *
  *      Description:  Implementation of allocator module.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:  Jan Treibig (jt), jan.treibig@gmail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -99,7 +99,8 @@ allocator_allocateVector(
         bstring domainString,
         int init_per_thread)
 {
-    int i;
+    (void)stride;
+
     size_t bytesize = 0;
     const AffinityDomain* domain = NULL;
     int errorCode;
@@ -110,9 +111,15 @@ allocator_allocateVector(
     bytesize = (size+offset) * typesize;
     elements = alignment / typesize;
 
-    for (i=0;i<domains->numberOfAffinityDomains;i++)
+    if ((bytesize == 0) || (elements == 0)) {
+        fprintf(stderr, "Error: Streams too small for all HW threads in the workgroup\n");
+        exit(EXIT_FAILURE);
+    }
+
+#pragma GCC diagnostic ignored "-Wnonnull"
+    for (size_t i=0;i<domains->numberOfAffinityDomains;i++)
     {
-        if (strncmp(domains->domains[i].tag, bdata(domainString), strlen(domains->domains[i].tag)) == 0)
+        if (strcmp(domains->domains[i].tag, bdata(domainString)) == 0)
         {
             domain = domains->domains + i;
         }
