@@ -5,14 +5,14 @@
  *
  *      Description:  Benchmarking framework for likwid-bench
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:  Jan Treibig (jt), jan.treibig@gmail.com
  *               Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -97,7 +97,7 @@ runTest(void* arg)
     offset = data->threadId * size;
     //printf("Orig size %lu Size %lu\n", myData->size / data->numberOfThreads, size);
     if (size != vecsize && data->threadId == 0)
-        printf("Sanitizing vector length to a multiple of the loop stride from %d elements (%d bytes) to %d elements (%d bytes)\n", vecsize, vecsize*myData->test->bytes, size, size*myData->test->bytes);
+        printf("Sanitizing vector length to a multiple of the loop stride from %zu elements (%zu bytes) to %zu elements (%zu bytes)\n", vecsize, vecsize*myData->test->bytes, size, size*myData->test->bytes);
 
     /* pin the thread */
     likwid_pinThread(myData->processors[threadId]);
