@@ -5,14 +5,14 @@
  *
  *      Description:  Implementation of affinity module.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com,
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -56,6 +56,9 @@
 
 /* #####   EXPORTED VARIABLES   ########################################### */
 
+// TODO, convert these to uint32_t types, like they are in CpuTopology.
+// Generally, there are a lof of types, which can be safely converted to uint32_t,
+// but that would require bigger code changes.
 int *affinity_thread2core_lookup = NULL;
 int *affinity_thread2die_lookup = NULL;
 int *affinity_thread2socket_lookup = NULL;
@@ -86,7 +89,7 @@ AffinityDomains affinityDomains;
 static int
 getProcessorID(cpu_set_t* cpu_set)
 {
-    int processorId;
+    unsigned processorId;
     topology_init();
     CpuTopology_t cputopo = get_cpuTopology();
 
@@ -111,8 +114,7 @@ treeFillNextEntries(
     int numberOfEntries)
 {
     int counter = numberOfEntries;
-    int skip = 0;
-    int c, t, c_count = 0;
+    int c_count = 0;
     TreeNode* node = tree;
     TreeNode* thread;
     CpuTopology_t cputopo = get_cpuTopology();
@@ -125,7 +127,7 @@ treeFillNextEntries(
         node = tree_getNextNode(node);
         if ( node == NULL )
         {
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, Cannot find socket %d in topology tree, i);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "Cannot find socket %d in topology tree", i);
         }
     }
 
@@ -137,7 +139,7 @@ treeFillNextEntries(
 
         if ( node == NULL )
         {
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, Cannot find core %d in topology tree, i);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "Cannot find core %d in topology tree", i);
         }
     }
 
@@ -167,15 +169,17 @@ treeFillNextEntries(
     return numberOfEntries-counter;
 }
 
-static int get_id_of_type(hwloc_obj_t base, hwloc_obj_type_t type)
-{
-    hwloc_obj_t walker = base->parent;
-    while (walker && walker->type != type)
-        walker = walker->parent;
-    if (walker && walker->type == type)
-        return walker->os_index;
-    return -1;
-}
+// TODO At the time of commenting this out, it wasn't used anywhere. Is it safe
+// to remove this?
+//static int get_id_of_type(hwloc_obj_t base, hwloc_obj_type_t type)
+//{
+//    hwloc_obj_t walker = base->parent;
+//    while (walker && walker->type != type)
+//        walker = walker->parent;
+//    if (walker && walker->type == type)
+//        return walker->os_index;
+//    return -1;
+//}
 
 #define AFF_FREE_AND_RESET(ptr) if (ptr != NULL) { free(ptr); ptr = NULL; }
 
@@ -184,8 +188,7 @@ static int create_lookups()
     int err = 0;
     int do_cache = 1;
     int cachelimit = 0;
-    int cacheIdx = -1;
-    int * tmp = NULL;
+    uint32_t *tmp = NULL;
     int num_tmp = 0;
     err = topology_init();
     if (err != 0)
@@ -373,7 +376,7 @@ static int create_lookups()
         }
         memset(sharedl3_lock, LOCK_INIT, cputopo->numHWThreads*sizeof(int));
     }
-    tmp = malloc(cputopo->numHWThreads * sizeof(int));
+    tmp = malloc(cputopo->numHWThreads * sizeof(tmp[0]));
     if (!tmp)
     {
         AFF_FREE_AND_RESET(sharedl3_lock);
@@ -391,7 +394,6 @@ static int create_lookups()
         return -ENOMEM;
     }
 
-    int num_pu = cputopo->numHWThreads;
     if (cputopo->numCacheLevels == 0)
     {
         do_cache = 0;
@@ -399,9 +401,8 @@ static int create_lookups()
     if (do_cache)
     {
         cachelimit = cputopo->cacheLevels[cputopo->numCacheLevels-1].threads;
-        cacheIdx = -1;
     }
-    for (int pu_idx = 0; pu_idx < num_pu; pu_idx++)
+    for (unsigned pu_idx = 0; pu_idx < cputopo->numHWThreads; pu_idx++)
     {
         HWThread* t = &cputopo->threadPool[pu_idx];
         int found = 0;
@@ -418,61 +419,58 @@ static int create_lookups()
             tmp[num_tmp++] = t->packageId;
         }
     }
-    for (int pu_idx = 0; pu_idx < num_pu; pu_idx++)
+    for (unsigned pu_idx = 0; pu_idx < cputopo->numHWThreads; pu_idx++)
     {
         HWThread* t = &cputopo->threadPool[pu_idx];
-        int hwthreadid = t->apicId;
-        int coreid = t->coreId;
-        int dieid = t->dieId;
-        int sockid = t->packageId;
-        int dies_per_socket = MAX(cputopo->numDies/cputopo->numSockets, 1);
-        affinity_thread2core_lookup[hwthreadid] = coreid;
-        affinity_thread2socket_lookup[hwthreadid] = sockid;
+        uint32_t apicId = t->apicId;
+        uint32_t dies_per_socket = MAX(cputopo->numDies/cputopo->numSockets, 1);
+        affinity_thread2core_lookup[apicId] = t->coreId;
+        affinity_thread2socket_lookup[apicId] = t->packageId;
         for (int j = 0; j < num_tmp; j++)
         {
-            if (affinity_thread2socket_lookup[hwthreadid] == tmp[j])
+            if (affinity_thread2socket_lookup[apicId] == (int)tmp[j])
             {
-                if (affinity_thread2socket_lookup[hwthreadid] != j)
+                if (affinity_thread2socket_lookup[apicId] != j)
                 {
-                    affinity_thread2socket_lookup[hwthreadid] = j;
-                    sockid = j;
+                    affinity_thread2socket_lookup[apicId] = j;
+                    t->packageId = j;
                 }
             }
         }
-        affinity_thread2die_lookup[hwthreadid] = (sockid * dies_per_socket) + dieid;
+        affinity_thread2die_lookup[apicId] = (t->packageId * dies_per_socket) + t->dieId;
         int memid = 0;
-        for (int n = 0; n < ntopo->numberOfNodes; n++)
+        for (unsigned n = 0; n < ntopo->numberOfNodes; n++)
         {
-            for (int i = 0; i < ntopo->nodes[n].numberOfProcessors; i++)
+            for (unsigned i = 0; i < ntopo->nodes[n].numberOfProcessors; i++)
             {
-                if (ntopo->nodes[n].processors[i] == hwthreadid)
+                if (ntopo->nodes[n].processors[i] == apicId)
                 {
                     memid = n;
                     break;
                 }
             }
         }
-        affinity_thread2numa_lookup[hwthreadid] = memid;
+        affinity_thread2numa_lookup[apicId] = memid;
         if (do_cache && cachelimit > 0)
         {
             int numberOfCoresPerCache = cachelimit/cputopo->numThreadsPerCore;
-            affinity_thread2sharedl3_lookup[hwthreadid] = coreid / numberOfCoresPerCache;
+            affinity_thread2sharedl3_lookup[apicId] = t->coreId / numberOfCoresPerCache;
         }
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, T %d T2C %d T2S %d T2D %d T2LLC %d T2M %d, hwthreadid,
-                                        affinity_thread2core_lookup[hwthreadid],
-                                        affinity_thread2socket_lookup[hwthreadid],
-                                        affinity_thread2die_lookup[hwthreadid],
-                                        affinity_thread2sharedl3_lookup[hwthreadid],
-                                        affinity_thread2numa_lookup[hwthreadid]);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "T %d T2C %d T2S %d T2D %d T2LLC %d T2M %d", apicId,
+                                        affinity_thread2core_lookup[apicId],
+                                        affinity_thread2socket_lookup[apicId],
+                                        affinity_thread2die_lookup[apicId],
+                                        affinity_thread2sharedl3_lookup[apicId],
+                                        affinity_thread2numa_lookup[apicId]);
     }
     free(tmp);
     return 0;
 }
 
-static int affinity_getPoolId(int cpuId)
+static int affinity_getPoolId(uint32_t cpuId)
 {
     CpuTopology_t cputopo = get_cpuTopology();
-    for (int i = 0; i < cputopo->numHWThreads; i++)
+    for (uint32_t i = 0; i < cputopo->numHWThreads; i++)
     {
         if (cputopo->threadPool[i].apicId == cpuId)
         {
@@ -494,7 +492,7 @@ static int affinity_countSocketCores(int len, int* hwthreads, int* helper)
             int found = 0;
             for (int k = 0; k < hidx; k++)
             {
-                if (helper[k] == cputopo->threadPool[pid].coreId)
+                if ((uint32_t)helper[k] == cputopo->threadPool[pid].coreId)
                 {
                     found = 1;
                 }
@@ -531,7 +529,7 @@ static int affinity_addNodeDomain(AffinityDomain* domain, int* help)
         }
         int offset = 0;
         int cores = 0;
-        for (int i = 0; i < MAX(cputopo->numSockets, 1); i++)
+        for (uint32_t i = 0; i < MAX(cputopo->numSockets, 1); i++)
         {
             int tmp = treeFillNextEntries(cputopo->topologyTree,
                                           domain->processorList, offset,
@@ -545,7 +543,7 @@ static int affinity_addNodeDomain(AffinityDomain* domain, int* help)
         domain->numberOfCores = cores;
         domain->tag[0] = 'N';
         domain->tag[1] = '\0';
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity domain N: %d HW threads on %d cores, domain->numberOfProcessors, domain->numberOfCores);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Affinity domain N: %d HW threads on %d cores", domain->numberOfProcessors, domain->numberOfCores);
         return 0;
     }
     return -EINVAL;
@@ -572,7 +570,7 @@ static int affinity_addSocketDomain(int socket, AffinityDomain* domain, int* hel
             free(domain->processorList);
             return -ENOMEM;
         }
-        int tmp = treeFillNextEntries(cputopo->topologyTree,
+        uint32_t tmp = treeFillNextEntries(cputopo->topologyTree,
                                       domain->processorList,
                                       0,
                                       socket, 0,
@@ -582,7 +580,7 @@ static int affinity_addSocketDomain(int socket, AffinityDomain* domain, int* hel
         domain->numberOfProcessors = tmp;
         domain->numberOfCores = affinity_countSocketCores(domain->numberOfProcessors, domain->processorList, help);
         snprintf(domain->tag, 9, "S%d", socket);
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity domain S%d: %d HW threads on %d cores, socket, domain->numberOfProcessors, domain->numberOfCores);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Affinity domain S%d: %d HW threads on %d cores", socket, domain->numberOfProcessors, domain->numberOfCores);
         return 0;
     }
     return -EINVAL;
@@ -601,7 +599,6 @@ static int affinity_addDieDomain(int socket, int die, AffinityDomain* domain, in
         int dieId = (socket * numDiesPerSocket) + die;
         int numCoresPerDie = cputopo->numCoresPerSocket/numDiesPerSocket;
         int numThreadsPerDie = numCoresPerDie * cputopo->numThreadsPerCore;
-        int coreOffset = die * numCoresPerDie;
         domain->processorList = malloc(numThreadsPerDie * sizeof(int));
         if (!domain->processorList)
         {
@@ -625,7 +622,7 @@ static int affinity_addDieDomain(int socket, int die, AffinityDomain* domain, in
         domain->numberOfProcessors = tmp;
         domain->numberOfCores = affinity_countSocketCores(domain->numberOfProcessors, domain->processorList, help);
         snprintf(domain->tag, 9, "D%d", dieId);
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity domain D%d: %d HW threads on %d cores, dieId, domain->numberOfProcessors, domain->numberOfCores);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Affinity domain D%d: %d HW threads on %d cores", dieId, domain->numberOfProcessors, domain->numberOfCores);
         return 0;
     }
     return -EINVAL;
@@ -667,7 +664,7 @@ static int affinity_addCacheDomain(int socket, int cacheId, AffinityDomain* doma
         domain->numberOfProcessors = tmp;
         domain->numberOfCores = affinity_countSocketCores(domain->numberOfProcessors, domain->processorList, help);
         snprintf(domain->tag, 9, "C%d", cid);
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity domain C%d: %d HW threads on %d cores, cid, domain->numberOfProcessors, domain->numberOfCores);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Affinity domain C%d: %d HW threads on %d cores", cid, domain->numberOfProcessors, domain->numberOfCores);
         return 0;
     }
     return -EINVAL;
@@ -684,22 +681,22 @@ static int _affinity_addMemoryDomain(int nodeId, AffinityDomain* domain, int* he
     }
     if (cputopo && numatopo)
     {
-        if (nodeId >= 0 && nodeId < numatopo->numberOfNodes)
+        if (nodeId >= 0 && (uint32_t)nodeId < numatopo->numberOfNodes)
         {
             domain->processorList = malloc(numatopo->nodes[nodeId].numberOfProcessors * sizeof(int));
             if (!domain->processorList)
             {
                 return -ENOMEM;
             }
-            domain->tag = malloc(10);
+            domain->tag = malloc(12);
             if (!domain->tag)
             {
                 free(domain->processorList);
                 return -ENOMEM;
             }
-            for (int i = 0; i < numatopo->nodes[nodeId].numberOfProcessors; i++)
+            for (unsigned i = 0; i < numatopo->nodes[nodeId].numberOfProcessors; i++)
             {
-                for (int j = 0; j < cputopo->numHWThreads; j++)
+                for (unsigned j = 0; j < cputopo->numHWThreads; j++)
                 {
                     if (cputopo->threadPool[j].apicId == numatopo->nodes[nodeId].processors[i] && cputopo->threadPool[j].inCpuSet == 1)
                     {
@@ -709,7 +706,7 @@ static int _affinity_addMemoryDomain(int nodeId, AffinityDomain* domain, int* he
             }
             domain->numberOfProcessors = num_hwthreads;
             domain->numberOfCores = affinity_countSocketCores(domain->numberOfProcessors, domain->processorList, help);
-            snprintf(domain->tag, 9, "M%d", nodeId);
+            snprintf(domain->tag, 12, "M%d", nodeId);
             return 0;
         }
     }
@@ -721,7 +718,7 @@ static int affinity_addMemoryDomain(int nodeId, AffinityDomain* domain, int* hel
     int err = _affinity_addMemoryDomain(nodeId, domain, help);
     if (err == 0)
     {
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity domain M%d: %d HW threads on %d cores, nodeId, domain->numberOfProcessors, domain->numberOfCores);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Affinity domain M%d: %d HW threads on %d cores", nodeId, domain->numberOfProcessors, domain->numberOfCores);
     }
     return err;
 }
@@ -749,7 +746,7 @@ static int affinity_addCudaDomain(int nodeId, AffinityDomain* domain, int offset
                 if (err == 0)
                 {
                     snprintf(domain->tag, 9, "G%d", nodeId+offset);
-                    DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity domain %s: %d HW threads on %d cores, domain->tag, domain->numberOfProcessors, domain->numberOfCores);
+                    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Affinity domain %s: %d HW threads on %d cores", domain->tag, domain->numberOfProcessors, domain->numberOfCores);
                     return 0;
                 }
             }
@@ -781,14 +778,15 @@ static int affinity_addRocmDomain(int nodeId, AffinityDomain* domain, int offset
                 err = _affinity_addMemoryDomain(rocmdev->numaNode, domain, help);
                 if (err == 0)
                 {
+                    // TODO where does 9 come from? Please replace this with a meaningful constant
                     snprintf(domain->tag, 9, "G%d", nodeId+offset);
-                    DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity domain %s: %d HW threads on %d cores, domain->tag, domain->numberOfProcessors, domain->numberOfCores);
+                    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Affinity domain %s: %d HW threads on %d cores", domain->tag, domain->numberOfProcessors, domain->numberOfCores);
                     return 0;
                 }
             }
             else
             {
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, Skipping affinity domain G%d because NUMA node unknown, nodeId);
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "Skipping affinity domain G%d because NUMA node unknown", nodeId);
             }
         }
     }
@@ -799,16 +797,11 @@ static int affinity_addRocmDomain(int nodeId, AffinityDomain* domain, int offset
 /* #####   FUNCTION DEFINITIONS  -  EXPORTED FUNCTIONS   ################## */
 
 int
-affinity_init()
+affinity_init(void)
 {
     int err = 0;
     int numberOfDomains = 1; /* all systems have the node domain */
-    int finalNumberOfDomains = 0;
-    int currentDomain;
-    int subCounter = 0;
-    int offset = 0;
     int domid = 0;
-    int tmp = 0;
     if (affinity_initialized == 1)
     {
         return 0;
@@ -828,21 +821,23 @@ affinity_init()
     NumaTopology_t numatopo = get_numaTopology();
 
 #ifdef LIKWID_WITH_NVMON
+    int doCudaDomains = 1;
     int numCudaDomains = 0;
     CudaTopology_t cudatopo = NULL;
     err = topology_cuda_init();
     if (err != 0)
     {
-        return err;
+        doCudaDomains = 0;
     }
 #endif
 #ifdef LIKWID_WITH_ROCMON
+    int doRocmDomains = 1;
     int numRocmDomains = 0;
     RocmTopology_t rocmtopo = NULL;
     err = topology_rocm_init();
     if (err != 0)
     {
-        return err;
+        doRocmDomains = 0;
     }
 #endif
 
@@ -860,52 +855,58 @@ affinity_init()
     /* determine total number of domains */
     numberOfDomains = 1;
     numberOfDomains += cputopo->numSockets;
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity: Socket domains %d, cputopo->numSockets);
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Affinity: Socket domains %d", cputopo->numSockets);
     numberOfDomains += (cputopo->numDies > 0 ? cputopo->numDies : cputopo->numSockets);
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity: CPU die domains %d, (cputopo->numDies > 0 ? cputopo->numDies : cputopo->numSockets));
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Affinity: CPU die domains %d", (cputopo->numDies > 0 ? cputopo->numDies : cputopo->numSockets));
     if (doCacheDomains && cputopo->numCacheLevels > 0)
     {
         numberOfProcessorsPerCache = cputopo->cacheLevels[cputopo->numCacheLevels-1].threads;
         numberOfCoresPerCache = numberOfProcessorsPerCache / cputopo->numThreadsPerCore;
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity: CPU cores per LLC %d, numberOfCoresPerCache);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Affinity: CPU cores per LLC %d", numberOfCoresPerCache);
         int numCachesPerSocket = cputopo->numCoresPerSocket / numberOfCoresPerCache;
         numberOfCacheDomains = cputopo->numSockets * MAX(numCachesPerSocket, 1);
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity: Cache domains %d, numberOfCacheDomains);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Affinity: Cache domains %d", numberOfCacheDomains);
         numberOfDomains += numberOfCacheDomains;
     }
     numberOfDomains += numatopo->numberOfNodes;
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity: NUMA domains %d, numatopo->numberOfNodes);
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Affinity: NUMA domains %d", numatopo->numberOfNodes);
 #if defined(LIKWID_WITH_NVMON) || defined(LIKWID_WITH_ROCMON)
     int gpuDomains = 0;
 #ifdef LIKWID_WITH_NVMON
-    cudatopo = get_cudaTopology();
-    for (int i = 0; i < cudatopo->numDevices; i++)
+    if (doCudaDomains)
     {
-        CudaDevice* dev = &cudatopo->devices[i];
-        if (dev->numaNode >= 0)
+        cudatopo = get_cudaTopology();
+        for (int i = 0; i < cudatopo->numDevices; i++)
         {
-            numCudaDomains++;
+            CudaDevice* dev = &cudatopo->devices[i];
+            if (dev->numaNode >= 0)
+            {
+                numCudaDomains++;
+            }
         }
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Affinity: CUDA domains %d (%d device(s))", numCudaDomains, cudatopo->numDevices);
+        gpuDomains += numCudaDomains;
     }
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity: CUDA domains %d (%d device(s)), numCudaDomains, cudatopo->numDevices);
-    gpuDomains += numCudaDomains;
 #endif
 #ifdef LIKWID_WITH_ROCMON
-    rocmtopo = get_rocmTopology();
-    for (int i = 0; i < rocmtopo->numDevices; i++)
+    if (doRocmDomains)
     {
-        RocmDevice* dev = &rocmtopo->devices[i];
-        if (dev->numaNode >= 0)
+        rocmtopo = get_rocmTopology();
+        for (int i = 0; i < rocmtopo->numDevices; i++)
         {
-            numRocmDomains++;
+            RocmDevice* dev = &rocmtopo->devices[i];
+            if (dev->numaNode >= 0)
+            {
+                numRocmDomains++;
+            }
         }
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Affinity: ROCm domains %d (%d device(s))", numRocmDomains, rocmtopo->numDevices);
+        gpuDomains += numRocmDomains;
     }
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity: ROCm domains %d (%d device(s)), numRocmDomains, rocmtopo->numDevices);
-    gpuDomains += numRocmDomains;
 #endif
     numberOfDomains += gpuDomains;
 #endif
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, Affinity: All domains %d, numberOfDomains);
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Affinity: All domains %d", numberOfDomains);
 
     domains = (AffinityDomain*) malloc(numberOfDomains * sizeof(AffinityDomain));
     if (!domains)
@@ -926,20 +927,18 @@ affinity_init()
     if (!err)
     {
         domid++;
-        finalNumberOfDomains++;
     }
     /* Socket domains */
-    for (int i = 0; i < cputopo->numSockets; i++)
+    for (unsigned i = 0; i < cputopo->numSockets; i++)
     {
         err = affinity_addSocketDomain(i, &domains[domid], helper);
         if (!err)
         {
             domid++;
-            finalNumberOfDomains++;
         }
     }
     /* CPU die domains */
-    for (int i = 0; i < cputopo->numSockets; i++)
+    for (unsigned i = 0; i < cputopo->numSockets; i++)
     {
         int numDiesPerSocket = 1;
         if (cputopo->numDies > 0)
@@ -952,14 +951,13 @@ affinity_init()
             if (!err)
             {
                 domid++;
-                finalNumberOfDomains++;
             }
         }
     }
     /* Last level cache domains */
     if (doCacheDomains && cputopo->numCacheLevels > 0)
     {
-        for (int i = 0; i < cputopo->numSockets; i++)
+        for (unsigned i = 0; i < cputopo->numSockets; i++)
         {
             int numThreadPerCache = cputopo->cacheLevels[cputopo->numCacheLevels-1].threads;
             int numCoresPerCache = numThreadPerCache / cputopo->numThreadsPerCore;
@@ -970,29 +968,29 @@ affinity_init()
                 if (!err)
                 {
                     domid++;
-                    finalNumberOfDomains++;
                 }
             }
         }
     }
     /* Memory / NUMA domains */
-    for (int i = 0; i < numatopo->numberOfNodes; i++)
+    for (unsigned i = 0; i < numatopo->numberOfNodes; i++)
     {
         err = affinity_addMemoryDomain(i, &domains[domid], helper);
         if (!err)
         {
             domid++;
-            finalNumberOfDomains++;
         }
     }
 #ifdef LIKWID_WITH_NVMON
-    for (int i = 0; i < cudatopo->numDevices; i++)
+    if (doCudaDomains)
     {
-        err = affinity_addCudaDomain(i, &domains[domid], 0, helper);
-        if (!err)
+        for (int i = 0; i < cudatopo->numDevices; i++)
         {
-            domid++;
-            finalNumberOfDomains++;
+            err = affinity_addCudaDomain(i, &domains[domid], 0, helper);
+            if (!err)
+            {
+                domid++;
+            }
         }
     }
 #endif
@@ -1001,13 +999,15 @@ affinity_init()
 #ifdef LIKWID_WITH_NVMON
     gpuOffset = numCudaDomains;
 #endif
-    for (int i = 0; i < rocmtopo->numDevices; i++)
+    if (doRocmDomains)
     {
-        err = affinity_addRocmDomain(i, &domains[domid], gpuOffset, helper);
-        if (!err)
+        for (int i = 0; i < rocmtopo->numDevices; i++)
         {
-            domid++;
-            finalNumberOfDomains++;
+            err = affinity_addRocmDomain(i, &domains[domid], gpuOffset, helper);
+            if (!err)
+            {
+                domid++;
+            }
         }
     }
 #endif
@@ -1038,7 +1038,7 @@ affinity_init()
 }
 
 void
-affinity_finalize()
+affinity_finalize(void)
 {
     if (affinity_initialized == 0)
     {
@@ -1048,7 +1048,7 @@ affinity_finalize()
     {
         return;
     }
-    for ( int i=0; i < affinityDomains.numberOfAffinityDomains; i++ )
+    for ( unsigned i=0; i < affinityDomains.numberOfAffinityDomains; i++ )
     {
         if (affinityDomains.domains[i].tag != NULL)
         {
@@ -1140,7 +1140,7 @@ affinity_finalize()
 }
 
 int
-affinity_processGetProcessorId()
+affinity_processGetProcessorId(void)
 {
     int ret;
     cpu_set_t cpu_set;
@@ -1156,7 +1156,7 @@ affinity_processGetProcessorId()
 }
 
 int
-affinity_threadGetProcessorId()
+affinity_threadGetProcessorId(void)
 {
     cpu_set_t  cpu_set;
     CPU_ZERO(&cpu_set);
@@ -1224,7 +1224,7 @@ affinity_getDomain(char* domain)
 }
 
 void
-affinity_printDomains()
+affinity_printDomains(void)
 {
     for ( int i=0; i < affinity_numberOfDomains; i++ )
     {
