@@ -5,13 +5,13 @@
  *
  *      Description:  Header file for interface to the access daemon for the access module.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -30,10 +30,12 @@
 #ifndef ACCESS_CLIENT_H
 #define ACCESS_CLIENT_H
 
-int access_client_init(int cpu_id);
-int access_client_read(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t *data);
-int access_client_write(PciDeviceIndex dev, const int cpu_id, uint32_t reg, uint64_t data);
-void access_client_finalize(int cpu_id);
-int access_client_check(PciDeviceIndex dev, int cpu_id);
+#include <stdint.h>
+
+int access_client_init(uint32_t cpu_id);
+int access_client_read(PciDeviceIndex dev, uint32_t cpu_id, uint32_t reg, uint64_t *data);
+int access_client_write(PciDeviceIndex dev, uint32_t cpu_id, uint32_t reg, uint64_t data);
+void access_client_finalize(uint32_t cpu_id);
+int access_client_check(PciDeviceIndex dev, uint32_t cpu_id);
 
 #endif /* ACCESS_CLIENT_H */
