@@ -5,13 +5,13 @@
  *
  *      Description:  Header File frequency module.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -40,8 +40,7 @@ extern char* daemon_path;
 #if !defined(__ARM_ARCH_7A__) && !defined(__ARM_ARCH_8A) && !defined(_ARCH_PPC)
 static int isAMD()
 {
-    unsigned int eax,ebx,ecx,edx;
-    eax = 0x0;
+    unsigned int eax = 0,ebx,ecx = 0,edx;
     CPUID(eax,ebx,ecx,edx);
     if (ecx == 0x444d4163)
         return 1;
