@@ -5,14 +5,14 @@
  *
  *      Description:  Header File of likwid Marker API
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Authors:  Thomas Gruber (tg), thomas.roehl@googlemail.com
  *
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -31,6 +31,17 @@
 #ifndef LIKWID_MARKER_H
 #define LIKWID_MARKER_H
 
+#ifdef LIKWID_NVMON
+#ifndef LIKWID_WITH_NVMON
+#define LIKWID_WITH_NVMON
+#endif
+#endif
+
+#ifdef LIKWID_ROCMON
+#ifndef LIKWID_WITH_ROCMON
+#define LIKWID_WITH_ROCMON
+#endif
+#endif
 
 /** \addtogroup MarkerAPI Marker API module
 *  @{
@@ -149,9 +160,6 @@ Shortcut for nvmon_markerWriteFile() with \a filename if compiled with -DLIKWID_
 /** @}*/
 
 #ifdef LIKWID_NVMON
-#ifndef LIKWID_WITH_NVMON
-#define LIKWID_WITH_NVMON
-#endif
 #include <likwid.h>
 #define NVMON_MARKER_INIT nvmon_markerInit()
 #define NVMON_MARKER_THREADINIT
@@ -225,9 +233,6 @@ Shortcut for rocmon_markerWriteFile() with \a filename if compiled with -DLIKWID
 /** @}*/
 
 #ifdef LIKWID_ROCMON
-#ifndef LIKWID_WITH_ROCMON
-#define LIKWID_WITH_ROCMON
-#endif
 #include <likwid.h>
 #define ROCMON_MARKER_INIT rocmon_markerInit()
 #define ROCMON_MARKER_THREADINIT rocmon_markerThreadInit()
