@@ -5,13 +5,13 @@
  *
  *      Description:  Header File of perfmon module for ARM A15.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,7 +27,8 @@
  *
  * =======================================================================================
  */
-
+#ifndef PERFMON_A15_H
+#define PERFMON_A15_H
 
 #include <perfmon_a15_events.h>
 #include <perfmon_a15_counters.h>
@@ -247,3 +248,5 @@ static int perfmon_numArchEventsA15 = NUM_ARCH_EVENTS_A15;
 //    }
 //    return 0;
 //}
+
+#endif //PERFMON_A15_H
