@@ -6,13 +6,13 @@
  *      Description:  Header File of perfmon module for ARM A57 and Marvell
  *                    Thunder X2.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -28,6 +28,9 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_A57_H
+#define PERFMON_A57_H
+
 #include <perfmon_a57_events.h>
 #include <perfmon_a57_counters.h>
 #include <perfmon_cavtx2_events.h>
@@ -251,3 +254,5 @@ static int perfmon_numArchEventsCavTx2 = NUM_ARCH_EVENTS_CAVTX2;
 //    }
 //    return 0;
 //}
+
+#endif //PERFMON_A57_H
