@@ -5,13 +5,13 @@
  *
  *      Description:  Counter Header File of perfmon module for Fujitsu A64FX
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,6 +27,8 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_A64FX_COUNTERS_H
+#define PERFMON_A64FX_COUNTERS_H
 
 #define NUM_COUNTERS_A64FX 8
 
@@ -42,9 +44,11 @@ static RegisterMap a64fx_counter_map[NUM_COUNTERS_A64FX] = {
 };
 
 static BoxMap a64fx_box_map[NUM_UNITS] = {
-    [PMC] = {0, 0, 0, 0, 0, 0, 32},
+    [PMC] = {0, 0, 0, 0, 0, 0, 32, 0, 0},
 };
 
 static char* a64fx_translate_types[NUM_UNITS] = {
     [PMC] = "/sys/bus/event_source/devices/armv8_pmuv3_0",
 };
+
+#endif //PERFMON_A64FX_COUNTERS_H
