@@ -5,13 +5,13 @@
  *
  *      Description:  Header File of perfmon module for HiSilicon chips.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2022 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,11 +27,15 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_HISILICON_H
+#define PERFMON_HISILICON_H
+
 #ifndef NUM_ARCH_EVENTS_A57
 #include <perfmon_a57_events.h>
 #endif
 #include <perfmon_hisilicon_counters.h>
 
-
 static int perfmon_numCountersHiSiliconTsv110 = NUM_COUNTERS_HISILICON_TSV110;
 static int perfmon_numArchEventsHiSiliconTsv110 = NUM_ARCH_EVENTS_A57;
+
+#endif //PERFMON_HISILICON_H
