@@ -5,13 +5,13 @@
  *
  *      Description:  Common definitions for Intel Nehalem EX and Westmere EX
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,6 +27,8 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_NEHALEMEX_WESTMEREEX_COMMON_H
+#define PERFMON_NEHALEMEX_WESTMEREEX_COMMON_H
 
 #ifndef PERFMON_NEX_WEX_COMMON
 #define PERFMON_NEX_WEX_COMMON
@@ -122,3 +124,5 @@ static uint64_t nex_wex_rbox_regs[2][NUM_RBOX_REG_TYPES][4] = {
 };
 
 #endif
+
+#endif //PERFMON_NEHALEMEX_WESTMEREEX_COMMON_H
