@@ -5,13 +5,13 @@
  *
  *      Description:  Header File of perfmon module for perf_event kernel interface.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,6 +27,8 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_PERFEVENT_H
+#define PERFMON_PERFEVENT_H
 
 #include <error.h>
 #include <affinity.h>
@@ -104,7 +106,7 @@ int perfevent_paranoid_value()
     if (fd == NULL)
     {
         errno = EPERM;
-        ERROR_PRINT(Linux kernel has no perf_event support. Cannot access /proc/sys/kernel/perf_event_paranoid);
+        ERROR_PRINT("Linux kernel has no perf_event support. Cannot access /proc/sys/kernel/perf_event_paranoid");
         return paranoid;
     }
     size_t read = fread(buff, sizeof(char), 100, fd);
@@ -132,7 +134,7 @@ int perfevent_apple_m1_pmc_type_select(int cpu_id, enum apple_m1_pmc_type *type)
     fd = fopen(bdata(fname), "r");
     if (fd == NULL)
     {
-        ERROR_PRINT(Failed to detect PMU type for Apple M1);
+        ERROR_PRINT("Failed to detect PMU type for Apple M1");
         bdestroy(fname);
         return errno;
     }
@@ -152,7 +154,7 @@ int perfevent_apple_m1_pmc_type_select(int cpu_id, enum apple_m1_pmc_type *type)
     }
     else
     {
-        ERROR_PRINT(Cannot read %s, bdata(fname));
+        ERROR_PRINT("Cannot read %s", bdata(fname));
     }
     bdestroy(fname);
     return -1;
@@ -166,7 +168,7 @@ int perfmon_init_perfevent(int cpu_id)
     if (getuid() != 0 && perf_event_paranoid > 2)
     {
         errno = EPERM;
-        ERROR_PRINT(Cannot use performance monitoring with perf_event_paranoid = %d, perf_event_paranoid);
+        ERROR_PRINT("Cannot use performance monitoring with perf_event_paranoid = %d", perf_event_paranoid);
         return -(cpu_id+1);
     }
 
@@ -176,11 +178,10 @@ int perfmon_init_perfevent(int cpu_id)
     lock_acquire((int*) &sharedl3_lock[affinity_thread2sharedl3_lookup[cpu_id]], cpu_id);
     lock_acquire((int*) &die_lock[affinity_thread2die_lookup[cpu_id]], cpu_id);
     lock_acquire((int*) &core_lock[affinity_thread2core_lookup[cpu_id]], cpu_id);
+    
     if (cpu_event_fds == NULL)
     {
-        cpu_event_fds = malloc(cpuid_topology.numHWThreads * sizeof(int*));
-        for (int i=0; i < cpuid_topology.numHWThreads; i++)
-            cpu_event_fds[i] = NULL;
+        cpu_event_fds = lw_calloc(cpuid_topology.numHWThreads, sizeof(*cpu_event_fds));
     }
     if (cpu_event_fds[cpu_id] == NULL)
     {
@@ -193,11 +194,17 @@ int perfmon_init_perfevent(int cpu_id)
         active_cpus += 1;
     }
     perf_event_num_cpus = cpuid_topology.numHWThreads;
-    if (cpuid_info.family == ZEN3_FAMILY && (cpuid_info.model == ZEN4_RYZEN || cpuid_info.model == ZEN4_RYZEN2 || cpuid_info.model == ZEN4_RYZEN_PRO || cpuid_info.model == ZEN4_EPYC ))
+    if (cpuid_info.family == ZEN3_FAMILY && (cpuid_info.model == ZEN4_RYZEN || cpuid_info.model == ZEN4_RYZEN2 || cpuid_info.model == ZEN4_RYZEN_PRO || cpuid_info.model == ZEN4_EPYC || cpuid_info.model == ZEN4_RYZEN3 ))
     {
         perfEventOptionNames[EVENT_OPTION_TID] = "threadmask";
         perfEventOptionNames[EVENT_OPTION_CID] = "coreid";
         perfEventOptionNames[EVENT_OPTION_SLICE] = "sliceid";
+    } else if (cpuid_info.family == ZEN5_FAMILY && (cpuid_info.model == ZEN5_EPYC)) {
+        perfEventOptionNames[EVENT_OPTION_TID] = "threadmask";
+        perfEventOptionNames[EVENT_OPTION_CID] = "coreid";
+        perfEventOptionNames[EVENT_OPTION_SLICE] = "sliceid";
+        perfEventOptionNames[EVENT_OPTION_MASK0] = "rdwrmask";
+
     }
     perf_event_initialized = 1;
     return 0;
@@ -352,6 +359,7 @@ int apply_event_config(struct perf_event_attr *attr, uint64_t optval, int num_fo
             case CONFIG2:
                 attr->config2 |= create_mask(optval, formats[i].start, formats[i].end);
                 break;
+            default: ;
         }
         optval = (optval >> ((formats[i].end - formats[i].start)+1));
     }
@@ -374,6 +382,8 @@ int parse_and_apply_event_config(char* base, char* optname, uint64_t optval, str
 
 int perf_fixed_setup(struct perf_event_attr *attr, RegisterIndex index, PerfmonEvent *event)
 {
+    (void)index;
+
     int err = -1;
     int ret = 0;
     int num_formats = 0;
@@ -453,6 +463,7 @@ int perf_fixed_setup(struct perf_event_attr *attr, RegisterIndex index, PerfmonE
                         case CONFIG2:
                             attr->config2 |= create_mask(eventConfig, formats[i].start, formats[i].end);
                             break;
+                        default: ;
                     }
                     eventConfig = (eventConfig >> ((formats[i].end - formats[i].start)+1));
                 }
@@ -471,6 +482,7 @@ int perf_fixed_setup(struct perf_event_attr *attr, RegisterIndex index, PerfmonE
 
 int perf_perf_setup(struct perf_event_attr *attr, RegisterIndex index, PerfmonEvent *event)
 {
+    (void)index;
     attr->type = PERF_TYPE_HARDWARE;
     attr->exclude_kernel = 1;
     attr->exclude_hv = 1;
@@ -482,7 +494,8 @@ int perf_perf_setup(struct perf_event_attr *attr, RegisterIndex index, PerfmonEv
 
 int perf_metrics_setup(struct perf_event_attr *attr, RegisterIndex index, PerfmonEvent *event)
 {
-    attr->type = 4;
+    (void)index;
+    attr->type = PERF_TYPE_RAW;
     attr->exclude_kernel = 1;
     attr->exclude_hv = 1;
     attr->exclude_guest = 1;
@@ -494,6 +507,8 @@ int perf_metrics_setup(struct perf_event_attr *attr, RegisterIndex index, Perfmo
 
 int perf_pmc_setup(struct perf_event_attr *attr, RegisterIndex index, RegisterType type, PerfmonEvent *event)
 {
+    (void)index;
+
     int ret = 0;
     uint64_t offcore_flags = 0x0ULL;
     int num_formats = 0;
@@ -544,6 +559,7 @@ int perf_pmc_setup(struct perf_event_attr *attr, RegisterIndex index, RegisterTy
                 case CONFIG2:
                     attr->config2 |= create_mask(eventConfig, formats[i].start, formats[i].end);
                     break;
+                default: ;
             }
             eventConfig = (eventConfig >> ((formats[i].end - formats[i].start)+1));
         }
@@ -581,6 +597,7 @@ int perf_pmc_setup(struct perf_event_attr *attr, RegisterIndex index, RegisterTy
                 case CONFIG2:
                     attr->config2 |= create_mask(umask, formats[i].start, formats[i].end);
                     break;
+                default: ;
             }
             umask = (umask >> ((formats[i].end - formats[i].start)+1));
         }
@@ -589,7 +606,7 @@ int perf_pmc_setup(struct perf_event_attr *attr, RegisterIndex index, RegisterTy
 
     if (event->numberOfOptions > 0)
     {
-        for(int j = 0; j < event->numberOfOptions; j++)
+        for(size_t j = 0; j < event->numberOfOptions; j++)
         {
 
             switch (event->options[j].type)
@@ -623,6 +640,7 @@ int perf_pmc_setup(struct perf_event_attr *attr, RegisterIndex index, RegisterTy
                                 case CONFIG2:
                                     attr->config2 |= create_mask(optval, formats[i].start, formats[i].end);
                                     break;
+                                default: ;
                             }
                             optval = (optval >> ((formats[i].end - formats[i].start)+1));
                         }
@@ -673,6 +691,7 @@ int perf_pmc_setup(struct perf_event_attr *attr, RegisterIndex index, RegisterTy
                     case CONFIG2:
                         attr->config2 |= create_mask(optval, formats[i].start, formats[i].end);
                         break;
+                    default: ;
                 }
                 optval = (optval >> ((formats[i].end - formats[i].start)+1));
             }
@@ -706,6 +725,9 @@ int perf_pmc_setup(struct perf_event_attr *attr, RegisterIndex index, RegisterTy
         free(formats);
     }
 #endif
+    if (cpuid_info.family == ZEN5_FAMILY && cpuid_info.model == ZEN5_EPYC && event->eventId == 0xFFF) {
+        memset(attr, 0, sizeof(struct perf_event_attr));
+    }
     return 0;
 }
 
@@ -725,13 +747,14 @@ int perf_uncore_setup(struct perf_event_attr *attr, RegisterType type, PerfmonEv
         return EPERM;
     }
     attr->type = 0;
-    DEBUG_PRINT(DEBUGLEV_DEVELOP, Get information for uncore counters from folder(s): %s, translate_types[type]);
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Get information for uncore counters from folder(s): %s", translate_types[type]);
     perf_folder = bfromcstr(translate_types[type]);
     folders = bsplit(perf_folder, ' ');
     bdestroy(perf_folder);
     perf_folder = NULL;
     for (int i = 0; i < folders->qty; i++)
     {
+#pragma GCC diagnostic ignored "-Wnonnull"
         if (!access(bdata(folders->entry[i]), R_OK|X_OK))
         {
             perf_folder = bstrcpy(folders->entry[i]);
@@ -748,7 +771,7 @@ int perf_uncore_setup(struct perf_event_attr *attr, RegisterType type, PerfmonEv
     {
         if ((type == UBOX)||(type == UBOXFIX))
         {
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, Get information for uncore counters from folder /sys/bus/event_source/devices/uncore_arb);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "Get information for uncore counters from folder /sys/bus/event_source/devices/uncore_arb");
             perf_type = read_perf_event_type("/sys/bus/event_source/devices/uncore_arb");
         }
     }
@@ -828,12 +851,12 @@ int perf_uncore_setup(struct perf_event_attr *attr, RegisterType type, PerfmonEv
             if (type >= CBOX0 && type <= CBOX59 && cpuid_info.isIntel && num_formats > 1
                 && (cpuid_info.model == ICELAKEX1 || cpuid_info.model == ICELAKEX2 || cpuid_info.model == SAPPHIRERAPIDS))
             {
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, Applying special umask handling for CBOXes of Intel ICX and SPR chips);
-                for(int j = 0; j < event->numberOfOptions; j++)
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "Applying special umask handling for CBOXes of Intel ICX and SPR chips");
+                for(size_t j = 0; j < event->numberOfOptions; j++)
                 {
                     if (event->options[j].type == EVENT_OPTION_MATCH0)
                     {
-                        DEBUG_PRINT(DEBUGLEV_DEVELOP, 0x%lX (0x%lX | (0x%lX << (%d - %d))), umask | (event->options[j].value << (formats[0].end - formats[0].start)), umask, event->options[j].value, formats[0].end, formats[0].start);
+                        DEBUG_PRINT(DEBUGLEV_DEVELOP, "0x%lX (0x%lX | (0x%lX << (%d - %d)))", umask | (event->options[j].value << (formats[0].end - formats[0].start)), umask, event->options[j].value, formats[0].end, formats[0].start);
                         umask |= (event->options[j].value << (formats[0].end - formats[0].start + 1));
                         break;
                     }
@@ -841,11 +864,11 @@ int perf_uncore_setup(struct perf_event_attr *attr, RegisterType type, PerfmonEv
             }
             for (int i = 0; i < num_formats && umask != 0x0; i++)
             {
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, Format %s from %d-%d with value 0x%lX, perfEventOptionNames[EVENT_OPTION_GENERIC_UMASK], formats[i].start, formats[i].end, umask);
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "Format %s from %d-%d with value 0x%lX", perfEventOptionNames[EVENT_OPTION_GENERIC_UMASK], formats[i].start, formats[i].end, umask);
                 switch(formats[i].reg)
                 {
                     case CONFIG:
-                        DEBUG_PRINT(DEBUGLEV_DEVELOP, Adding 0x%lX to 0x%X, create_mask(umask, formats[i].start, formats[i].end), attr->config);
+                        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Adding 0x%lX to 0x%llX", create_mask(umask, formats[i].start, formats[i].end), attr->config);
                         attr->config |= create_mask(umask, formats[i].start, formats[i].end);
                         break;
                     case CONFIG1:
@@ -854,6 +877,7 @@ int perf_uncore_setup(struct perf_event_attr *attr, RegisterType type, PerfmonEv
                     case CONFIG2:
                         attr->config2 |= create_mask(umask, formats[i].start, formats[i].end);
                         break;
+                    default: ;
                 }
                 umask = (umask >> ((formats[i].end - formats[i].start)+1));
             }
@@ -864,7 +888,7 @@ int perf_uncore_setup(struct perf_event_attr *attr, RegisterType type, PerfmonEv
 
     if (event->numberOfOptions > 0)
     {
-        for(int j = 0; j < event->numberOfOptions; j++)
+        for(uint64_t j = 0; j < event->numberOfOptions; j++)
         {
             switch (event->options[j].type)
             {
@@ -879,6 +903,8 @@ int perf_uncore_setup(struct perf_event_attr *attr, RegisterType type, PerfmonEv
                 case EVENT_OPTION_IN_TRANS_ABORT:
                 case EVENT_OPTION_MATCH0:
                 case EVENT_OPTION_MATCH1:
+                case EVENT_OPTION_MASK0:
+                case EVENT_OPTION_MASK1:
                 case EVENT_OPTION_TID:
                 case EVENT_OPTION_CID:
                 case EVENT_OPTION_SLICE:
@@ -901,6 +927,7 @@ int perf_uncore_setup(struct perf_event_attr *attr, RegisterType type, PerfmonEv
                                 case CONFIG2:
                                     attr->config2 |= create_mask(optval, formats[i].start, formats[i].end);
                                     break;
+                                default: ;
                             }
                             optval = (optval >> ((formats[i].end - formats[i].start)+1));
                         }
@@ -921,12 +948,12 @@ int perf_uncore_setup(struct perf_event_attr *attr, RegisterType type, PerfmonEv
         }
     }
 
-    if (type != POWER && cpuid_info.family == ZEN3_FAMILY && (cpuid_info.model == ZEN4_RYZEN || cpuid_info.model == ZEN4_RYZEN2 || cpuid_info.model == ZEN4_RYZEN_PRO || cpuid_info.model == ZEN4_EPYC))
+    if (type != POWER && cpuid_info.family == ZEN3_FAMILY && (cpuid_info.model == ZEN4_RYZEN || cpuid_info.model == ZEN4_RYZEN2 || cpuid_info.model == ZEN4_RYZEN_PRO || cpuid_info.model == ZEN4_EPYC || cpuid_info.model == ZEN4_RYZEN3))
     {
         int got_cid = 0;
         int got_slices = 0;
         int got_tid = 0;
-        for(int j = 0; j < event->numberOfOptions; j++)
+        for(uint64_t j = 0; j < event->numberOfOptions; j++)
         {
             switch (event->options[j].type)
             {
@@ -939,21 +966,22 @@ int perf_uncore_setup(struct perf_event_attr *attr, RegisterType type, PerfmonEv
                 case EVENT_OPTION_SLICE:
                     got_slices = 1;
                     break;
+                default: ;
             }
         }
         if (!got_cid)
         {
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, AMD Zen4 L3: activate counting for all cores);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "AMD Zen4 L3: activate counting for all cores");
             attr->config |= (1ULL<<47);
         }
         if (!got_tid)
         {
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, AMD Zen4 L3: activate counting for all SMT threads);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "AMD Zen4 L3: activate counting for all SMT threads");
             attr->config |= (0x3ULL<<56);
         }
         if (!got_slices)
         {
-            DEBUG_PRINT(DEBUGLEV_DEVELOP, AMD Zen4 L3: activate counting for all L3 slices);
+            DEBUG_PRINT(DEBUGLEV_DEVELOP, "AMD Zen4 L3: activate counting for all L3 slices");
             attr->config |= (1ULL<<46);
         }
     }
@@ -987,10 +1015,10 @@ int perfmon_setupCountersThread_perfevent(
     {
         if (allpid == -1)
         {
-            DEBUG_PRINT(DEBUGLEV_INFO, PID of application required. Use LIKWID_PERF_PID env variable or likwid-perfctr options);
+            DEBUG_PRINT(DEBUGLEV_INFO, "PID of application required. Use LIKWID_PERF_PID env variable or likwid-perfctr options");
             return -EPERM;
         }
-        DEBUG_PRINT(DEBUGLEV_DEVELOP, Using PID %d for perf_event measurements, allpid);
+        DEBUG_PRINT(DEBUGLEV_DEVELOP, "Using PID %d for perf_event measurements", allpid);
     }
 
     if (getenv("LIKWID_PERF_FLAGS") != NULL)
@@ -1015,7 +1043,7 @@ int perfmon_setupCountersThread_perfevent(
         is_uncore = 0;
         ret = 1;
         RegisterIndex index = eventSet->events[i].index;
-        if (cpu_event_fds[cpu_id][index] != -1)
+        if (((int)index > perfmon_numCounters) || (cpu_event_fds[cpu_id][index] != -1))
         {
             continue;
         }
@@ -1035,7 +1063,7 @@ int perfmon_setupCountersThread_perfevent(
                 {
                     continue;
                 }
-                VERBOSEPRINTREG(cpu_id, index, attr.config, SETUP_FIXED);
+                VERBOSEPRINTREG(cpu_id, index, attr.config, "SETUP_FIXED");
                 break;
             case PERF:
                 ret = perf_perf_setup(&attr, index, event);
@@ -1043,7 +1071,7 @@ int perfmon_setupCountersThread_perfevent(
                 {
                     continue;
                 }
-                VERBOSEPRINTREG(cpu_id, index, attr.config, SETUP_PERF);
+                VERBOSEPRINTREG(cpu_id, index, attr.config, "SETUP_PERF");
                 break;
             case METRICS:
                 ret = perf_metrics_setup(&attr, index, event);
@@ -1051,7 +1079,7 @@ int perfmon_setupCountersThread_perfevent(
                 {
                     continue;
                 }
-                VERBOSEPRINTREG(cpu_id, index, attr.config, SETUP_METRICS);
+                VERBOSEPRINTREG(cpu_id, index, attr.config, "SETUP_METRICS");
                 break;
             case PMC:
                 pmc_lock = 1;
@@ -1074,18 +1102,18 @@ int perfmon_setupCountersThread_perfevent(
                 else if (cpuid_info.vendor == APPLE_M1 && cpuid_info.model == APPLE_M1_STUDIO)
                 {
                     enum apple_m1_pmc_type ptype = M1_UNKNOWN;
-                    DEBUG_PRINT(DEBUGLEV_DEVELOP, Getting real perf_event type for HWThread %d, cpu_id);
+                    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Getting real perf_event type for HWThread %d", cpu_id);
                     ret = perfevent_apple_m1_pmc_type_select(cpu_id, &ptype);
                     if (ret == 0)
                     {
                         switch (ptype)
                         {
                             case M1_ICESTORM:
-                                DEBUG_PRINT(DEBUGLEV_DEVELOP, HWThread %d is an icestorm core, cpu_id);
+                                DEBUG_PRINT(DEBUGLEV_DEVELOP, "HWThread %d is an icestorm core", cpu_id);
                                 type = IPMC;
                                 break;
                             case M1_FIRESTORM:
-                                DEBUG_PRINT(DEBUGLEV_DEVELOP, HWThread %d is an firestorm core, cpu_id);
+                                DEBUG_PRINT(DEBUGLEV_DEVELOP, "HWThread %d is an firestorm core", cpu_id);
                                 type = FPMC;
                                 break;
                             default:
@@ -1095,7 +1123,7 @@ int perfmon_setupCountersThread_perfevent(
                     }
                     else
                     {
-                        ERROR_PRINT(Failed getting real perf_event type for HWThread %d, cpu_id);
+                        ERROR_PRINT("Failed getting real perf_event type for HWThread %d", cpu_id);
                         pmc_lock = 0;
                     }
                 }
@@ -1103,34 +1131,34 @@ int perfmon_setupCountersThread_perfevent(
                 if (pmc_lock)
                 {
                     ret = perf_pmc_setup(&attr, index, type, event);
-                    VERBOSEPRINTREG(cpu_id, index, attr.config, SETUP_PMC);
+                    VERBOSEPRINTREG(cpu_id, index, attr.config, "SETUP_PMC");
                 }
                 break;
             case POWER:
                 if (cpuid_info.isIntel && socket_lock[affinity_thread2socket_lookup[cpu_id]] == cpu_id)
                 {
                     has_lock = 1;
-                    VERBOSEPRINTREG(cpu_id, index, attr.config, SETUP_POWER);
+                    VERBOSEPRINTREG(cpu_id, index, attr.config, "SETUP_POWER");
                     ret = perf_uncore_setup(&attr, type, event);
                 }
-                else if ((cpuid_info.family == ZEN_FAMILY || cpuid_info.family == ZEN3_FAMILY))
+                else if ((cpuid_info.family == ZEN_FAMILY) || (cpuid_info.family == ZEN3_FAMILY) || (cpuid_info.family == ZEN5_FAMILY))
                 {
                     if (event->eventId == 0x01 && core_lock[affinity_thread2core_lookup[cpu_id]] == cpu_id)
                     {
                         has_lock = 1;
-                        VERBOSEPRINTREG(cpu_id, index, attr.config, SETUP_POWER);
+                        VERBOSEPRINTREG(cpu_id, index, attr.config, "SETUP_POWER");
                         ret = perf_uncore_setup(&attr, type, event);
                     }
                     else if (event->eventId == 0x02 && socket_lock[affinity_thread2socket_lookup[cpu_id]] == cpu_id)
                     {
                         has_lock = 1;
-                        VERBOSEPRINTREG(cpu_id, index, attr.config, SETUP_POWER);
+                        VERBOSEPRINTREG(cpu_id, index, attr.config, "SETUP_POWER");
                         ret = perf_uncore_setup(&attr, type, event);
                     }
                     else if (event->eventId == 0x03 && sharedl3_lock[affinity_thread2sharedl3_lookup[cpu_id]] == cpu_id)
                     {
                         has_lock = 1;
-                        VERBOSEPRINTREG(cpu_id, index, attr.config, SETUP_POWER);
+                        VERBOSEPRINTREG(cpu_id, index, attr.config, "SETUP_POWER");
                         ret = perf_uncore_setup(&attr, type, event);
                     }
                 }
@@ -1312,6 +1340,44 @@ int perfmon_setupCountersThread_perfevent(
             case BBOX29:
             case BBOX30:
             case BBOX31:
+            case BBOX32:
+            case BBOX33:
+            case BBOX34:
+            case BBOX35:
+            case BBOX36:
+            case BBOX37:
+            case BBOX38:
+            case BBOX39:
+            case BBOX40:
+            case BBOX41:
+            case BBOX42:
+            case BBOX43:
+            case BBOX44:
+            case BBOX45:
+            case BBOX46:
+            case BBOX47:
+            case BBOX48:
+            case BBOX49:
+            case BBOX50:
+            case BBOX51:
+            case BBOX52:
+            case BBOX53:
+            case BBOX54:
+            case BBOX55:
+            case BBOX56:
+            case BBOX57:
+            case BBOX58:
+            case BBOX59:
+            case BBOX60:
+            case BBOX61:
+            case BBOX62:
+            case BBOX63:
+            case BBOX64:
+            case BBOX65:
+            case BBOX66:
+            case BBOX67:
+            case BBOX68:
+            case BBOX69:
             case EDBOX0:
             case EDBOX1:
             case EDBOX2:
@@ -1399,7 +1465,7 @@ int perfmon_setupCountersThread_perfevent(
                         has_lock = 1;
                     }
                 }
-                else if ((cpuid_info.family == ZEN_FAMILY || cpuid_info.family == ZEN3_FAMILY) && type == CBOX0)
+                else if ((cpuid_info.family == ZEN_FAMILY || cpuid_info.family == ZEN3_FAMILY || cpuid_info.family == ZEN5_FAMILY) && type == CBOX0)
                 {
                     if (sharedl3_lock[affinity_thread2sharedl3_lookup[cpu_id]] == cpu_id)
                     {
@@ -1425,14 +1491,19 @@ int perfmon_setupCountersThread_perfevent(
                 }
                 if ((cpuid_info.family == ARMV8_FAMILY) && (cpuid_info.part == NVIDIA_GRACE) && cpuid_topology.numSockets > 1)
                 {
-                    DEBUG_PRINT(DEBUGLEV_DEVELOP, Updating uncore type for socket %d on Nvidia Grace, affinity_thread2socket_lookup[cpu_id]);
+                    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Updating uncore type for socket %d on Nvidia Grace", affinity_thread2socket_lookup[cpu_id]);
                     type += affinity_thread2socket_lookup[cpu_id];
                 }
+                if ((cpuid_info.family == ZEN5_FAMILY) && (cpuid_info.model == ZEN5_EPYC) && (cpuid_topology.numSockets > 1))
+                {
+                    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Updating UMC uncore type for socket %d on AMD Zen5", affinity_thread2socket_lookup[cpu_id]);
+                    type += (affinity_thread2socket_lookup[cpu_id] * AMD_K1A_UMC_MAX_UNITS);
+                }
                 if (has_lock)
                 {
                     ret = perf_uncore_setup(&attr, type, event);
                     is_uncore = 1;
-                    VERBOSEPRINTREG(cpu_id, index, attr.config, SETUP_UNCORE);
+                    VERBOSEPRINTREG(cpu_id, index, attr.config, "SETUP_UNCORE");
                 }
                 break;
 #endif
@@ -1449,27 +1520,27 @@ int perfmon_setupCountersThread_perfevent(
 
             if (!is_uncore)
             {
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, perf_event_open: cpu_id=%d pid=%d flags=%d, cpu_id, curpid, allflags);
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "perf_event_open: cpu_id=%d pid=%d flags=%ld", cpu_id, curpid, allflags);
                 cpu_event_fds[cpu_id][index] = perf_event_open(&attr, curpid, cpu_id, -1, allflags);
             }
             else if ((perf_disable_uncore == 0) && (has_lock))
             {
                 if (perf_event_paranoid > 0 && getuid() != 0)
                 {
-                    DEBUG_PRINT(DEBUGLEV_INFO, Cannot measure Uncore with perf_event_paranoid value = %d, perf_event_paranoid);
+                    DEBUG_PRINT(DEBUGLEV_INFO, "Cannot measure Uncore with perf_event_paranoid value = %d", perf_event_paranoid);
                     perf_disable_uncore = 1;
                 }
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, perf_event_open: cpu_id=%d pid=%d flags=%d type=%d config=0x%llX disabled=%d inherit=%d exclusive=%d config1=0x%llX config2=0x%llX, cpu_id, curpid, allflags, attr.type, attr.config, attr.disabled, attr.inherit, attr.exclusive, attr.config1, attr.config2);
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "perf_event_open: cpu_id=%d pid=%d flags=%ld type=%d config=0x%llX disabled=%d inherit=%d exclusive=%d config1=0x%llX config2=0x%llX", cpu_id, curpid, allflags, attr.type, attr.config, attr.disabled, attr.inherit, attr.exclusive, attr.config1, attr.config2);
                 cpu_event_fds[cpu_id][index] = perf_event_open(&attr, curpid, cpu_id, -1, allflags);
             }
             else
             {
-                DEBUG_PRINT(DEBUGLEV_INFO, Unknown perf_event_paranoid value = %d, perf_event_paranoid);
+                DEBUG_PRINT(DEBUGLEV_INFO, "Unknown perf_event_paranoid value = %d", perf_event_paranoid);
             }
             if (cpu_event_fds[cpu_id][index] < 0)
             {
-                ERROR_PRINT(Setup of event %s on CPU %d failed: %s, event->name, cpu_id, strerror(errno));
-                DEBUG_PRINT(DEBUGLEV_DEVELOP, open error: cpu_id=%d pid=%d flags=%d type=%d config=0x%llX disabled=%d inherit=%d exclusive=%d config1=0x%llX config2=0x%llX, cpu_id, curpid, allflags, attr.type, attr.config, attr.disabled, attr.inherit, attr.exclusive, attr.config1, attr.config2);
+                ERROR_PRINT("Setup of event %s on CPU %d failed: %s", event->name, cpu_id, strerror(errno));
+                DEBUG_PRINT(DEBUGLEV_DEVELOP, "open error: cpu_id=%d pid=%d flags=%ld type=%d config=0x%llX disabled=%d inherit=%d exclusive=%d config1=0x%llX config2=0x%llX", cpu_id, curpid, allflags, attr.type, attr.config, attr.disabled, attr.inherit, attr.exclusive, attr.config1, attr.config2);
             }
             if (group_fd < 0)
             {
@@ -1482,7 +1553,7 @@ int perfmon_setupCountersThread_perfevent(
         {
             if (is_uncore && perf_disable_uncore == 0 && perf_event_paranoid > 0 && getuid() != 0)
             {
-                DEBUG_PRINT(DEBUGLEV_INFO, Cannot measure Uncore with perf_event_paranoid value = %d, perf_event_paranoid);
+                DEBUG_PRINT(DEBUGLEV_INFO, "Cannot measure Uncore with perf_event_paranoid value = %d", perf_event_paranoid);
                 perf_disable_uncore = 1;
             }
         }
@@ -1492,7 +1563,6 @@ int perfmon_setupCountersThread_perfevent(
 
 int perfmon_startCountersThread_perfevent(int thread_id, PerfmonEventSet* eventSet)
 {
-    int ret = 0;
     int cpu_id = groupSet->threads[thread_id].processorId;
     if (!perf_event_initialized)
     {
@@ -1505,20 +1575,23 @@ int perfmon_startCountersThread_perfevent(int thread_id, PerfmonEventSet* eventS
             RegisterIndex index = eventSet->events[i].index;
             if (cpu_event_fds[cpu_id][index] < 0)
                 continue;
-            VERBOSEPRINTREG(cpu_id, 0x0, 0x0, RESET_COUNTER);
+            VERBOSEPRINTREG(cpu_id, 0x0, 0x0, "RESET_COUNTER");
             ioctl(cpu_event_fds[cpu_id][index], PERF_EVENT_IOC_RESET, 0);
             PerfmonCounter *c = &eventSet->events[i].threadCounter[thread_id];
             c->startData = 0x0ULL;
             c->counterData = 0x0ULL;
             if (eventSet->events[i].type == POWER)
             {
-                ret = read(cpu_event_fds[cpu_id][index],
-                        &eventSet->events[i].threadCounter[thread_id].startData,
-                        sizeof(long long));
+                int ret = read(cpu_event_fds[cpu_id][index],
+                               &eventSet->events[i].threadCounter[thread_id].startData,
+                               sizeof(long long));
+                if (ret != sizeof(long long))
+                {
+                    ERROR_PRINT("Failed to read start data of RAPL counter\n");
+                    return -(thread_id+1);
+                }
             }
-            VERBOSEPRINTREG(cpu_id, 0x0,
-                            c->startData,
-                            START_COUNTER);
+            VERBOSEPRINTREG(cpu_id, 0x0, c->startData, "START_COUNTER");
             ioctl(cpu_event_fds[cpu_id][index], PERF_EVENT_IOC_ENABLE, 0);
         }
     }
@@ -1541,11 +1614,11 @@ int perfmon_stopCountersThread_perfevent(int thread_id, PerfmonEventSet* eventSe
             RegisterIndex index = eventSet->events[i].index;
             if (cpu_event_fds[cpu_id][index] < 0)
                 continue;
-            VERBOSEPRINTREG(cpu_id, cpu_event_fds[cpu_id][index], 0x0, FREEZE_COUNTER);
+            VERBOSEPRINTREG(cpu_id, cpu_event_fds[cpu_id][index], 0x0, "FREEZE_COUNTER");
             ioctl(cpu_event_fds[cpu_id][index], PERF_EVENT_IOC_DISABLE, 0);
             tmp = 0x0LL;
             ret = read(cpu_event_fds[cpu_id][index], &tmp, sizeof(long long));
-            VERBOSEPRINTREG(cpu_id, cpu_event_fds[cpu_id][index], tmp, READ_COUNTER);
+            VERBOSEPRINTREG(cpu_id, cpu_event_fds[cpu_id][index], tmp, "READ_COUNTER");
             if (ret == sizeof(long long))
             {
 #if defined(__ARM_ARCH_8A)
@@ -1576,7 +1649,7 @@ int perfmon_stopCountersThread_perfevent(int thread_id, PerfmonEventSet* eventSe
 
             }
             ioctl(cpu_event_fds[cpu_id][index], PERF_EVENT_IOC_RESET, 0);
-            VERBOSEPRINTREG(cpu_id, cpu_event_fds[cpu_id][index], 0x0, RESET_COUNTER);
+            VERBOSEPRINTREG(cpu_id, cpu_event_fds[cpu_id][index], 0x0, "RESET_COUNTER");
         }
     }
     return 0;
@@ -1598,11 +1671,11 @@ int perfmon_readCountersThread_perfevent(int thread_id, PerfmonEventSet* eventSe
             RegisterIndex index = eventSet->events[i].index;
             if (cpu_event_fds[cpu_id][index] < 0)
                 continue;
-            VERBOSEPRINTREG(cpu_id, cpu_event_fds[cpu_id][index], 0x0, FREEZE_COUNTER);
+            VERBOSEPRINTREG(cpu_id, cpu_event_fds[cpu_id][index], 0x0, "FREEZE_COUNTER");
             ioctl(cpu_event_fds[cpu_id][index], PERF_EVENT_IOC_DISABLE, 0);
             tmp = 0x0LL;
             ret = read(cpu_event_fds[cpu_id][index], &tmp, sizeof(long long));
-            VERBOSEPRINTREG(cpu_id, cpu_event_fds[cpu_id][index], tmp, READ_COUNTER);
+            VERBOSEPRINTREG(cpu_id, cpu_event_fds[cpu_id][index], tmp, "READ_COUNTER");
             if (ret == sizeof(long long))
             {
 #if defined(__ARM_ARCH_8A)
@@ -1631,7 +1704,7 @@ int perfmon_readCountersThread_perfevent(int thread_id, PerfmonEventSet* eventSe
 #endif
                 eventSet->events[i].threadCounter[thread_id].counterData = tmp;
             }
-            VERBOSEPRINTREG(cpu_id, cpu_event_fds[cpu_id][index], 0x0, UNFREEZE_COUNTER);
+            VERBOSEPRINTREG(cpu_id, cpu_event_fds[cpu_id][index], 0x0, "UNFREEZE_COUNTER");
             ioctl(cpu_event_fds[cpu_id][index], PERF_EVENT_IOC_ENABLE, 0);
         }
     }
@@ -1651,6 +1724,7 @@ int perfmon_finalizeCountersThread_perfevent(int thread_id, PerfmonEventSet* eve
                 {
                     ioctl(cpu_event_fds[cpu_id][j], PERF_EVENT_IOC_DISABLE, 0);
                     ioctl(cpu_event_fds[cpu_id][j], PERF_EVENT_IOC_RESET, 0);
+                    VERBOSEPRINTREG(cpu_id, cpu_event_fds[cpu_id][j], 0x0, "CLEAR_COUNTER");
                     close(cpu_event_fds[cpu_id][j]);
                     cpu_event_fds[cpu_id][j] = -1;
                     if (j < eventSet->numberOfEvents && eventSet->events[j].threadCounter[thread_id].init == TRUE)
@@ -1684,3 +1758,5 @@ void __attribute__((destructor (101))) close_perfmon_perfevent(void)
         cpu_event_fds = NULL;
     }
 }
+
+#endif //PERFMON_PERFEVENT_H
