@@ -5,13 +5,13 @@
  *
  *      Description:  Counter header File of perfmon module for IBM POWER8.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,6 +27,8 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_POWER8_COUNTERS_H
+#define PERFMON_POWER8_COUNTERS_H
 
 #define NUM_COUNTERS_POWER8 7
 
@@ -47,3 +49,5 @@ static BoxMap power8_box_map[NUM_UNITS] = {
 static char* power8_translate_types[NUM_UNITS] = {
     [PMC] = "/sys/bus/event_source/devices/cpu",
 };
+
+#endif //PERFMON_POWER8_COUNTERS_H
