@@ -5,13 +5,13 @@
  *
  *      Description:  Counter header File of perfmon module for IBM POWER9.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,6 +27,8 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_POWER9_COUNTERS_H
+#define PERFMON_POWER9_COUNTERS_H
 
 #define NUM_COUNTERS_POWER9 48
 
@@ -116,3 +118,5 @@ static char* power9_translate_types[NUM_UNITS] = {
     [BBOX0] = "/sys/bus/event_source/devices/nest_mcs01_imc",
     [BBOX1] = "/sys/bus/event_source/devices/nest_mcs23_imc",
 };
+
+#endif //PERFMON_POWER9_COUNTERS_H
