@@ -5,13 +5,13 @@
  *
  *      Description: Counter header file of perfmon module for Intel Atom (Silvermont)
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2015 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,6 +27,9 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_SILVERMONT_COUNTERS_H
+#define PERFMON_SILVERMONT_COUNTERS_H
+
 #include <registers.h>
 
 #define NUM_COUNTERS_CORE_SILVERMONT 6
@@ -45,15 +48,17 @@ static RegisterMap silvermont_counter_map[NUM_COUNTERS_SILVERMONT] = {
     {"PMC0", PMC3, PMC, MSR_PERFEVTSEL0, MSR_PMC0, MSR_OFFCORE_RESP0, 0, SVM_VALID_OPTIONS_PMC},
     {"PMC1", PMC4, PMC, MSR_PERFEVTSEL1, MSR_PMC1, MSR_OFFCORE_RESP1, 0, SVM_VALID_OPTIONS_PMC},
     /* Temperature Sensor*/
-    {"TMP0", PMC5, THERMAL, 0, IA32_THERM_STATUS, 0, 0},
+    {"TMP0", PMC5, THERMAL, 0, IA32_THERM_STATUS, 0, 0, EVENT_OPTION_NONE_MASK},
     /* RAPL counters */
-    {"PWR0", PMC6, POWER, 0, MSR_PKG_ENERGY_STATUS, 0, 0},
-    {"PWR1", PMC7, POWER, 0, MSR_PP0_ENERGY_STATUS, 0, 0}
+    {"PWR0", PMC6, POWER, 0, MSR_PKG_ENERGY_STATUS, 0, 0, EVENT_OPTION_NONE_MASK},
+    {"PWR1", PMC7, POWER, 0, MSR_PP0_ENERGY_STATUS, 0, 0, EVENT_OPTION_NONE_MASK}
 };
 
 static BoxMap silvermont_box_map[NUM_UNITS] = {
-    [PMC] = {MSR_PERF_GLOBAL_CTRL, MSR_PERF_GLOBAL_STATUS, MSR_PERF_GLOBAL_OVF_CTRL, -1, 0, 0, 48},
-    [FIXED] = {MSR_PERF_GLOBAL_CTRL, MSR_PERF_GLOBAL_STATUS, MSR_PERF_GLOBAL_OVF_CTRL, -1, 0, 0, 48},
-    [THERMAL] = {0, 0, 0, 0, 0, MSR_DEV, 8},
-    [POWER] = {0, 0, 0, 0, 0, MSR_DEV, 32}
+    [PMC] = {MSR_PERF_GLOBAL_CTRL, MSR_PERF_GLOBAL_STATUS, MSR_PERF_GLOBAL_OVF_CTRL, -1, 0, 0, 48, 0, 0},
+    [FIXED] = {MSR_PERF_GLOBAL_CTRL, MSR_PERF_GLOBAL_STATUS, MSR_PERF_GLOBAL_OVF_CTRL, -1, 0, 0, 48, 0, 0},
+    [THERMAL] = {0, 0, 0, 0, 0, MSR_DEV, 8, 0, 0},
+    [POWER] = {0, 0, 0, 0, 0, MSR_DEV, 32, 0, 0}
 };
+
+#endif //PERFMON_SILVERMONT_COUNTERS_H
