@@ -5,13 +5,13 @@
  *
  *      Description:  Header file of perfmon module for AMD Family 19 (ZEN4C)
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tg), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2017 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -27,17 +27,65 @@
  *
  * =======================================================================================
  */
+#ifndef PERFMON_ZEN4C_H
+#define PERFMON_ZEN4C_H
 
 #include <perfmon_zen4c_events.h>
 #include <perfmon_zen4c_counters.h>
 #include <error.h>
 #include <affinity.h>
-
-
+#include <cpuid.h>
 
 static int perfmon_numCountersZen4c = NUM_COUNTERS_ZEN4C;
 static int perfmon_numArchEventsZen4c = NUM_ARCH_EVENTS_ZEN4C;
 
+int zen4c_init_counter_map(int num_in_counters, RegisterMap * in_counters, int* num_out_counters, RegisterMap ** out_counters) {
+    unsigned eax = 0x80000022, ebx = 0x0, ecx = 0x0, edx = 0x0;
+    CPUID(eax, ebx, ecx, edx);
+    int umc_count = (ebx >> 16) & 0xFF;
+    int umc_units = bitMask_popcount(ecx);
+    DEBUG_PRINT(DEBUGLEV_DEVELOP, "Creating runtime counter map for AMD Zen4c with %d UMC units", umc_units);
+    if ((umc_count == 0) || (umc_units == 0)) {
+        RegisterMap * out = malloc(num_in_counters * sizeof(RegisterMap));
+        if (!out) {
+            return -ENOMEM;
+        }
+        memcpy(out, in_counters, num_in_counters * sizeof(RegisterMap));
+        *num_out_counters = num_in_counters;
+        *out_counters = out;
+    } else {
+        int umc_pmcs = umc_count/umc_units;
+        int outcount = 0;
+        
+        RegisterMap * out = malloc((num_in_counters + umc_count) * sizeof(RegisterMap));
+        if (!out) {
+            return -ENOMEM;
+        }
+        memcpy(out, in_counters, num_in_counters * sizeof(RegisterMap));
+
+        int umcoff = 0;
+        for (int i = 0; i < umc_units; i++) {
+            RegisterType unit_type = BBOX0+i;
+            for (int j = 0; j < umc_pmcs; j++) {
+                RegisterMap* out_umc = &out[num_in_counters+umcoff];
+                out_umc->index = num_in_counters+umcoff;
+                out_umc->type = unit_type;
+                snprintf(out_umc->key, 127, "UMC%dC%d", i, j);
+                out_umc->configRegister = MSR_AMD19_UMC_PERFEVTSEL0 + umcoff;
+                out_umc->counterRegister = MSR_AMD19_UMC_PMC0 + umcoff;
+                out_umc->counterRegister2 = 0x0;
+                out_umc->device = MSR_DEV;
+                out_umc->optionMask = ZEN4C_VALID_OPTIONS_UMC;
+                umcoff++;
+            }
+        }
+        *num_out_counters = num_in_counters + umcoff;
+        *out_counters = out;
+    }
+
+    return 0;
+}
+
 int perfmon_init_zen4c(int cpu_id)
 {
     lock_acquire((int*) &socket_lock[affinity_thread2socket_lookup[cpu_id]], cpu_id);
@@ -50,20 +98,20 @@ int perfmon_init_zen4c(int cpu_id)
 
 int zen4c_fixed_setup(int cpu_id, RegisterIndex index, PerfmonEvent* event)
 {
+    (void)cpu_id;
+    (void)index;
     uint64_t flags = 0x0ULL;
-    cpu_id++;
-    index++;
     switch (event->eventId)
     {
         case 0x1:
             flags |= (1ULL << AMD_K17_INST_RETIRE_ENABLE_BIT);
-            VERBOSEPRINTREG(cpu_id, 0x00, LLU_CAST flags, SETUP_FIXC0);
+            VERBOSEPRINTREG(cpu_id, 0x00, LLU_CAST flags, "SETUP_FIXC0");
             break;
         case 0x2:
         case 0x3:
             break;
         default:
-            fprintf(stderr, "Unknown fixed event 0x%X\n", event->eventId);
+            fprintf(stderr, "Unknown fixed event 0x%lX\n", event->eventId);
             break;
     }
     return flags;
@@ -82,7 +130,7 @@ int zen4c_pmc_setup(int cpu_id, RegisterIndex index, PerfmonEvent* event)
     // Currently no option for host/guest counting
     if (event->numberOfOptions > 0)
     {
-        for(int j=0;j<event->numberOfOptions;j++)
+        for(uint64_t j=0;j<event->numberOfOptions;j++)
         {
             switch (event->options[j].type)
             {
@@ -105,7 +153,7 @@ int zen4c_pmc_setup(int cpu_id, RegisterIndex index, PerfmonEvent* event)
     }
     if (flags != currentConfig[cpu_id][index])
     {
-        VERBOSEPRINTREG(cpu_id, counter_map[index].configRegister, LLU_CAST flags, SETUP_PMC);
+        VERBOSEPRINTREG(cpu_id, counter_map[index].configRegister, LLU_CAST flags, "SETUP_PMC");
         CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, counter_map[index].configRegister, flags));
         currentConfig[cpu_id][index] = flags;
     }
@@ -128,7 +176,7 @@ int zen4c_cache_setup(int cpu_id, RegisterIndex index, PerfmonEvent* event)
     flags |= ((event->eventId & AMD_K17_L3_EVSEL_MASK) << AMD_K17_L3_EVSEL_SHIFT);
     if (event->numberOfOptions > 0)
     {
-        for(int j=0;j<event->numberOfOptions;j++)
+        for(uint64_t j=0;j<event->numberOfOptions;j++)
         {
             switch (event->options[j].type)
             {
@@ -158,7 +206,7 @@ int zen4c_cache_setup(int cpu_id, RegisterIndex index, PerfmonEvent* event)
 
     if (flags != currentConfig[cpu_id][index])
     {
-        VERBOSEPRINTREG(cpu_id, counter_map[index].configRegister, LLU_CAST flags, SETUP_CBOX);
+        VERBOSEPRINTREG(cpu_id, counter_map[index].configRegister, LLU_CAST flags, "SETUP_CBOX");
         CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, counter_map[index].configRegister, flags));
         currentConfig[cpu_id][index] = flags;
     }
@@ -187,7 +235,45 @@ int zen4c_datafabric_setup(int cpu_id, RegisterIndex index, PerfmonEvent* event)
 
     if (flags != currentConfig[cpu_id][index])
     {
-        VERBOSEPRINTREG(cpu_id, counter_map[index].configRegister, LLU_CAST flags, SETUP_DF);
+        VERBOSEPRINTREG(cpu_id, counter_map[index].configRegister, LLU_CAST flags, "SETUP_DF");
+        CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, counter_map[index].configRegister, flags));
+        currentConfig[cpu_id][index] = flags;
+    }
+    return 0;
+}
+
+int zen4c_umc_setup(int cpu_id, RegisterIndex index, PerfmonEvent* event)
+{
+    uint64_t flags = 0x0ULL;
+    int has_tid = 0;
+    int has_cid = 0;
+    int has_slice = 0;
+
+    if (socket_lock[affinity_thread2socket_lookup[cpu_id]] != cpu_id)
+    {
+        return 0;
+    }
+
+    flags |= ((event->eventId & AMD_K19_UMC_EVSEL_MASK) << AMD_K19_UMC_EVSEL_SHIFT);
+
+    if (event->numberOfOptions > 0)
+    {
+        for(int j = 0; j < (int)event->numberOfOptions; j++)
+        {
+            switch (event->options[j].type)
+            {
+                case EVENT_OPTION_MASK0:
+                    flags |= ((uint64_t)(event->options[j].value & AMD_K19_UMC_RWMASK_MASK)) << AMD_K19_UMC_RWMASK_SHIFT;
+                    break;
+                default:
+                    break;
+            }
+        }
+    }
+
+    if (flags != currentConfig[cpu_id][index])
+    {
+        VERBOSEPRINTREG(cpu_id, counter_map[index].configRegister, LLU_CAST flags, "SETUP_UMC");
         CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, counter_map[index].configRegister, flags));
         currentConfig[cpu_id][index] = flags;
     }
@@ -202,7 +288,7 @@ int perfmon_setupCounterThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
 
     if (MEASURE_CORE(eventSet))
     {
-        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_CTRL, 0x0ULL, FREEZE_PMC_AND_FIXED)
+        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_CTRL, 0x0ULL, "FREEZE_PMC_AND_FIXED");
         CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, MSR_AMD19_GLOBAL_CTRL, 0x0ULL));
         CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, MSR_AMD19_GLOBAL_GLOBAL_OVF_CTRL, 0x3F));
     }
@@ -232,6 +318,72 @@ int perfmon_setupCounterThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
             case MBOX0:
                 zen4c_datafabric_setup(cpu_id, index, event);
                 break;
+            case BBOX0:
+            case BBOX1:
+            case BBOX2:
+            case BBOX3:
+            case BBOX4:
+            case BBOX5:
+            case BBOX6:
+            case BBOX7:
+            case BBOX8:
+            case BBOX9:
+            case BBOX10:
+            case BBOX11:
+            case BBOX12:
+            case BBOX13:
+            case BBOX14:
+            case BBOX15:
+            case BBOX16:
+            case BBOX17:
+            case BBOX18:
+            case BBOX19:
+            case BBOX20:
+            case BBOX21:
+            case BBOX22:
+            case BBOX23:
+            case BBOX24:
+            case BBOX25:
+            case BBOX26:
+            case BBOX27:
+            case BBOX28:
+            case BBOX29:
+            case BBOX30:
+            case BBOX31:
+            case BBOX32:
+            case BBOX33:
+            case BBOX34:
+            case BBOX35:
+            case BBOX36:
+            case BBOX37:
+            case BBOX38:
+            case BBOX39:
+            case BBOX40:
+            case BBOX41:
+            case BBOX42:
+            case BBOX43:
+            case BBOX44:
+            case BBOX45:
+            case BBOX46:
+            case BBOX47:
+            case BBOX48:
+            case BBOX49:
+            case BBOX50:
+            case BBOX51:
+            case BBOX52:
+            case BBOX53:
+            case BBOX54:
+            case BBOX55:
+            case BBOX56:
+            case BBOX57:
+            case BBOX58:
+            case BBOX59:
+            case BBOX60:
+            case BBOX61:
+            case BBOX62:
+            case BBOX63:
+                zen4c_umc_setup(cpu_id, index, event);
+                break;
             default:
                 break;
         }
@@ -241,9 +393,9 @@ int perfmon_setupCounterThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
     {
         uint64_t tmp = 0x0ULL;
         CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, MSR_AMD17_HW_CONFIG, &tmp));
-        VERBOSEPRINTREG(cpu_id, MSR_AMD17_HW_CONFIG, LLU_CAST tmp, READ_HW_CONFIG);
+        VERBOSEPRINTREG(cpu_id, MSR_AMD17_HW_CONFIG, LLU_CAST tmp, "READ_HW_CONFIG");
         tmp |= fixed_flags;
-        VERBOSEPRINTREG(cpu_id, MSR_AMD17_HW_CONFIG, LLU_CAST tmp, WRITE_HW_CONFIG)
+        VERBOSEPRINTREG(cpu_id, MSR_AMD17_HW_CONFIG, LLU_CAST tmp, "WRITE_HW_CONFIG");
         CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, MSR_AMD17_HW_CONFIG, tmp));
     }
     return 0;
@@ -254,7 +406,6 @@ int perfmon_startCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
     int haveSLock = 0;
     int haveL3Lock = 0;
     int haveCLock = 0;
-    int haveMLock = 0;
     uint64_t flags = 0x0ULL;
     uint64_t pmc_flags = 0x0ULL;
     int cpu_id = groupSet->threads[thread_id].processorId;
@@ -271,10 +422,6 @@ int perfmon_startCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
     {
         haveCLock = 1;
     }
-    if (numa_lock[affinity_thread2numa_lookup[cpu_id]] == cpu_id)
-    {
-        haveMLock = 1;
-    }
 
     for (int i=0;i < eventSet->numberOfEvents;i++)
     {
@@ -295,16 +442,16 @@ int perfmon_startCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
                 ((type == MBOX0) && (haveSLock)) ||
                 ((type == CBOX0) && (haveL3Lock)))
             {
-                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST 0x0ULL, RESET_CTR);
+                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST 0x0ULL, "RESET_CTR");
                 CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, counter, 0x0ULL));
                 CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, reg, &flags));
-                VERBOSEPRINTREG(cpu_id, reg, LLU_CAST flags, READ_CTRL);
+                VERBOSEPRINTREG(cpu_id, reg, LLU_CAST flags, "READ_CTRL");
                 flags |= (1ULL << AMD_K17_ENABLE_BIT);  /* enable flag */
                 if (type == PMC)
                 {
                     pmc_flags |= (1ULL << getCounterTypeOffset(index));
                 }
-                VERBOSEPRINTREG(cpu_id, reg, LLU_CAST flags, START_CTRL);
+                VERBOSEPRINTREG(cpu_id, reg, LLU_CAST flags, "START_CTRL");
                 CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, reg, flags));
             }
             else if (type == POWER)
@@ -317,13 +464,23 @@ int perfmon_startCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
                     continue;
                 CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, counter, &flags));
                 eventSet->events[i].threadCounter[thread_id].startData = flags;
-                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST flags, START_POWER);
+                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST flags, "START_POWER");
             }
             else if (type == FIXED)
             {
                 CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, counter, &flags));
                 eventSet->events[i].threadCounter[thread_id].startData = field64(flags, 0, box_map[type].regWidth);
-                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST field64(flags, 0, box_map[type].regWidth), START_FIXED);
+                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST field64(flags, 0, box_map[type].regWidth), "START_FIXED");
+            }
+            else if (haveSLock && type >= BBOX0 && type <= BBOX63)
+            {
+                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST 0x0ULL, "RESET_UMC_CTR");
+                CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, counter, 0x0ULL));
+                CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, reg, &flags));
+                VERBOSEPRINTREG(cpu_id, reg, LLU_CAST flags, "READ_UMC_CTRL");
+                flags |= (1ULL << AMD_K19_UMC_ENABLE_BIT);  /* enable flag */
+                VERBOSEPRINTREG(cpu_id, reg, LLU_CAST flags, "START_UMC_CTRL");
+                CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, reg, flags));
             }
             eventSet->events[i].threadCounter[thread_id].counterData = eventSet->events[i].threadCounter[thread_id].startData;
         }
@@ -331,9 +488,9 @@ int perfmon_startCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
 
     if (MEASURE_CORE(eventSet))
     {
-        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_GLOBAL_OVF_CTRL, LLU_CAST pmc_flags, CLEAR_PMC_OVERFLOW)
+        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_GLOBAL_OVF_CTRL, LLU_CAST pmc_flags, "CLEAR_PMC_OVERFLOW");
         CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, MSR_AMD19_GLOBAL_GLOBAL_OVF_CTRL, pmc_flags));
-        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_CTRL, LLU_CAST pmc_flags, UNFREEZE_PMC)
+        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_CTRL, LLU_CAST pmc_flags, "UNFREEZE_PMC");
         CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, MSR_AMD19_GLOBAL_CTRL, pmc_flags));
     }
 
@@ -358,7 +515,6 @@ int perfmon_stopCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
     int haveSLock = 0;
     int haveL3Lock = 0;
     int haveCLock = 0;
-    int haveMLock = 0;
     uint64_t counter_result = 0x0ULL;
     int cpu_id = groupSet->threads[thread_id].processorId;
 
@@ -374,13 +530,9 @@ int perfmon_stopCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
     {
         haveCLock = 1;
     }
-    if (numa_lock[affinity_thread2numa_lookup[cpu_id]] == cpu_id)
-    {
-        haveMLock = 1;
-    }
     if (MEASURE_CORE(eventSet))
     {
-        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_CTRL, 0x0ULL, FREEZE_PMC)
+        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_CTRL, 0x0ULL, "FREEZE_PMC");
         CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, MSR_AMD19_GLOBAL_CTRL, 0x0ULL));
     }
 
@@ -403,10 +555,10 @@ int perfmon_stopCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
             {
                 CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, reg, &flags));
                 flags &= ~(1ULL<<AMD_K17_ENABLE_BIT);  /* clear enable flag */
-                VERBOSEPRINTREG(cpu_id, reg, LLU_CAST flags, STOP_CTRL);
+                VERBOSEPRINTREG(cpu_id, reg, LLU_CAST flags, "STOP_CTRL");
                 CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, reg, flags));
                 CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, counter, &counter_result));
-                VERBOSEPRINTREG(cpu_id, reg, LLU_CAST counter_result, READ_CTR);
+                VERBOSEPRINTREG(cpu_id, reg, LLU_CAST counter_result, "READ_CTR");
                 if (type == PMC)
                 {
                     ZEN4C_CHECK_CORE_OVERFLOW(getCounterTypeOffset(index));
@@ -414,7 +566,7 @@ int perfmon_stopCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
                 else if (field64(counter_result, 0, box_map[type].regWidth) < eventSet->events[i].threadCounter[thread_id].counterData)
                 {
                     eventSet->events[i].threadCounter[thread_id].overflows++;
-                    VERBOSEPRINTREG(cpu_id, reg, LLU_CAST counter_result, OVERFLOW);
+                    VERBOSEPRINTREG(cpu_id, reg, LLU_CAST counter_result, "OVERFLOW");
                 }
             }
             else if (type == POWER)
@@ -429,10 +581,10 @@ int perfmon_stopCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
                 if (counter_result < eventSet->events[i].threadCounter[thread_id].counterData)
                 {
                     eventSet->events[i].threadCounter[thread_id].overflows++;
-                    VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, OVERFLOW_POWER)
+                    VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, "OVERFLOW_POWER");
                 }
 
-                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, STOP_POWER);
+                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, "STOP_POWER");
             }
             else if (type == FIXED)
             {
@@ -441,9 +593,23 @@ int perfmon_stopCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
                 if (counter_result < eventSet->events[i].threadCounter[thread_id].counterData)
                 {
                     eventSet->events[i].threadCounter[thread_id].overflows++;
-                    VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, OVERFLOW_FIXED)
+                    VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, "OVERFLOW_FIXED");
                 }
-                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, STOP_FIXED);
+                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, "STOP_FIXED");
+            }
+            else if (haveSLock && type >= BBOX0 && type <= BBOX63)
+            {
+                CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, counter, &counter_result));
+                VERBOSEPRINTREG(cpu_id, reg, LLU_CAST counter_result, "READ_UMC_CTR");
+                if ((counter_result >> (box_map[type].regWidth-1)) > 0)
+                {
+                    eventSet->events[i].threadCounter[thread_id].overflows++;
+                    VERBOSEPRINTREG(cpu_id, reg, LLU_CAST counter_result, "UMC_OVERFLOW");
+                }
+                CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, reg, &flags));
+                flags &= ~(1ULL<<AMD_K19_UMC_ENABLE_BIT);  /* clear enable flag */
+                VERBOSEPRINTREG(cpu_id, reg, LLU_CAST flags, "STOP_UMC_CTRL");
+                CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, reg, flags));
             }
             eventSet->events[i].threadCounter[thread_id].counterData = counter_result;
         }
@@ -458,7 +624,6 @@ int perfmon_readCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
     int haveSLock = 0;
     int haveL3Lock = 0;
     int haveCLock = 0;
-    int haveMLock = 0;
     uint64_t counter_result = 0x0ULL;
     int cpu_id = groupSet->threads[thread_id].processorId;
 
@@ -474,15 +639,11 @@ int perfmon_readCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
     {
         haveCLock = 1;
     }
-    if (numa_lock[affinity_thread2numa_lookup[cpu_id]] == cpu_id)
-    {
-        haveMLock = 1;
-    }
     if (MEASURE_CORE(eventSet))
     {
         CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, MSR_AMD19_GLOBAL_CTRL, &flags));
-        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_CTRL, LLU_CAST flags, SAFE_PMC_FLAGS)
-        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_CTRL, 0x0ULL, FREEZE_PMC)
+        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_CTRL, LLU_CAST flags, "SAFE_PMC_FLAGS");
+        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_CTRL, 0x0ULL, "FREEZE_PMC");
         CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, MSR_AMD19_GLOBAL_CTRL, 0x0ULL));
     }
 
@@ -504,7 +665,7 @@ int perfmon_readCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
                 ((type == CBOX0) && (haveL3Lock)))
             {
                 CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, counter, &counter_result));
-                VERBOSEPRINTREG(cpu_id, counter, counter_result, READ_CTR);
+                VERBOSEPRINTREG(cpu_id, counter, counter_result, "READ_CTR");
                 if (type == PMC)
                 {
                     ZEN4C_CHECK_CORE_OVERFLOW(getCounterTypeOffset(index));
@@ -523,11 +684,11 @@ int perfmon_readCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
                     continue;
                 if (counter == MSR_AMD19_RAPL_L3_STATUS && (!haveL3Lock))
                     continue;
-                CHECK_POWER_READ_ERROR(power_read(cpu_id, counter, (uint32_t*)&counter_result));
-                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, READ_POWER)
+                CHECK_POWER_READ_ERROR(power_read(cpu_id, counter, (uint64_t*)&counter_result));
+                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, "READ_POWER");
                 if (counter_result < eventSet->events[i].threadCounter[thread_id].counterData)
                 {
-                    VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, OVERFLOW_POWER)
+                    VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, "OVERFLOW_POWER");
                     eventSet->events[i].threadCounter[thread_id].overflows++;
                 }
                 *current = field64(counter_result, 0, box_map[type].regWidth);
@@ -535,19 +696,30 @@ int perfmon_readCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
             else if (type == FIXED)
             {
                 CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, counter, &counter_result));
-                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, READ_FIXED)
+                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, "READ_FIXED");
                 if (counter_result < eventSet->events[i].threadCounter[thread_id].counterData)
                 {
-                    VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, OVERFLOW_FIXED)
+                    VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, "OVERFLOW_FIXED");
                     eventSet->events[i].threadCounter[thread_id].overflows++;
                 }
                 *current = field64(counter_result, 0, box_map[type].regWidth);
             }
+            else if (haveSLock && type >= BBOX0 && type <= BBOX63)
+            {
+                CHECK_MSR_READ_ERROR(HPMread(cpu_id, MSR_DEV, counter, &counter_result));
+                VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, "READ_UMC_CTR");
+                if ((counter_result >> (box_map[type].regWidth-1)) > 0)
+                {
+                    eventSet->events[i].threadCounter[thread_id].overflows++;
+                    VERBOSEPRINTREG(cpu_id, counter, LLU_CAST counter_result, "UMC_OVERFLOW");
+                }
+                *current = field64(counter_result, 0, box_map[type].regWidth);
+            }
         }
     }
     if (MEASURE_CORE(eventSet))
     {
-        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_CTRL, LLU_CAST flags, UNFREEZE_PMC)
+        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_CTRL, LLU_CAST flags, "UNFREEZE_PMC");
         CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, MSR_AMD19_GLOBAL_CTRL, flags));
     }
     return 0;
@@ -557,7 +729,6 @@ int perfmon_readCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
 int perfmon_finalizeCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSet)
 {
     int haveSLock = 0;
-    int haveMLock = 0;
     int haveL3Lock = 0;
     uint64_t ovf_values_core = 0x0ULL;
     int cpu_id = groupSet->threads[thread_id].processorId;
@@ -570,11 +741,6 @@ int perfmon_finalizeCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSe
     {
         haveL3Lock = 1;
     }
-    if (numa_lock[affinity_thread2numa_lookup[cpu_id]] == cpu_id)
-    {
-        haveMLock = 1;
-    }
-
 
     for (int i=0;i < eventSet->numberOfEvents;i++)
     {
@@ -586,16 +752,17 @@ int perfmon_finalizeCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSe
         RegisterIndex index = eventSet->events[i].index;
         if ((type == PMC) ||
             ((type == MBOX0) && (haveSLock)) ||
-            ((type == CBOX0) && (haveL3Lock)))
+            ((type == CBOX0) && (haveL3Lock)) ||
+            ((type >= BBOX0 && type <= BBOX63) && (haveSLock)))
         {
             if (counter_map[index].configRegister != 0x0)
             {
-                VERBOSEPRINTREG(cpu_id, counter_map[index].configRegister, 0x0ULL, CLEAR_CTRL);
+                VERBOSEPRINTREG(cpu_id, counter_map[index].configRegister, 0x0ULL, "CLEAR_CTRL");
                 CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, counter_map[index].configRegister, 0x0ULL));
             }
             if (counter_map[index].counterRegister != 0x0)
             {
-                VERBOSEPRINTREG(cpu_id, counter_map[index].counterRegister, 0x0ULL, CLEAR_CTR);
+                VERBOSEPRINTREG(cpu_id, counter_map[index].counterRegister, 0x0ULL, "CLEAR_CTR");
                 CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, counter_map[index].counterRegister, 0x0ULL));
             }
             if (type == PMC)
@@ -617,10 +784,12 @@ int perfmon_finalizeCountersThread_zen4c(int thread_id, PerfmonEventSet* eventSe
     }
     if (MEASURE_CORE(eventSet))
     {
-        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_GLOBAL_OVF_CTRL, LLU_CAST ovf_values_core, CLEAR_GLOBAL_OVF)
+        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_GLOBAL_OVF_CTRL, LLU_CAST ovf_values_core, "CLEAR_GLOBAL_OVF");
         CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, MSR_AMD19_GLOBAL_GLOBAL_OVF_CTRL, ovf_values_core));
-        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_CTRL, LLU_CAST 0x0ULL, CLEAR_GLOBAL_CTRL)
+        VERBOSEPRINTREG(cpu_id, MSR_AMD19_GLOBAL_CTRL, LLU_CAST 0x0ULL, "CLEAR_GLOBAL_CTRL");
         CHECK_MSR_WRITE_ERROR(HPMwrite(cpu_id, MSR_DEV, MSR_AMD19_GLOBAL_CTRL, 0x0ULL));
     }
     return 0;
 }
+
+#endif //PERFMON_ZEN4C_H
