@@ -5,14 +5,14 @@
  *
  *      Description:  Header File of topology module.
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
  *                Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -114,6 +114,7 @@ struct topology_functions {
 #define TIGERLAKE1           0x8CU
 #define TIGERLAKE2           0x8DU
 #define SAPPHIRERAPIDS       0x8FU
+#define EMERALDRAPIDS        0xCFU
 #define ALDERLAKE1           0x97U
 #define ALDERLAKE2           0x9AU
 #define ALDERLAKE3           0xBFU
@@ -158,8 +159,10 @@ struct topology_functions {
 #define ZEN4_RYZEN      0x61
 #define ZEN4_RYZEN_PRO  0x08
 #define ZEN4_RYZEN2     0x74
+#define ZEN4_RYZEN3     0x75
 #define ZEN4_EPYC       0x11
 #define ZEN4_EPYC_BERGAMO 0xA0
+#define ZEN5_EPYC       0x02
 
 /* ARM */
 #define  ARM7L          0x3U
@@ -211,6 +214,7 @@ struct topology_functions {
 #define  NETBURST_FAMILY  0xFFU
 #define  ZEN_FAMILY       0x17U
 #define  ZEN3_FAMILY      0x19U
+#define  ZEN5_FAMILY      0x1AU
 #define  K15_FAMILY       0x15U
 #define  K16_FAMILY       0x16U
 #define  K10_FAMILY       0x10U
@@ -221,7 +225,7 @@ struct topology_functions {
 
 extern int cpu_count(cpu_set_t* set);
 extern int likwid_cpu_online(int cpu_id);
-extern int likwid_sysfs_list_len(char* sysfsfile);
+extern size_t likwid_sysfs_list_len(char* sysfsfile);
 
 static inline int cpuid_hasFeature(FeatureBit bit)
 {
