@@ -5,13 +5,13 @@
  *
  *      Description:  Interface to hwloc for NUMA topology
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:  Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -97,7 +97,6 @@ getTotalNodeMem(int nodeId)
     bstring totalString  = bformat("MemTotal:");
     bstring sysfilename = bformat("/sys/devices/system/node/node%d/meminfo", nodeId);
     bstring procfilename = bformat("/proc/meminfo");
-    char *sptr = bdata(procfilename);
 
     if (NULL != (fp = fopen (bdata(sysfilename), "r")))
     {
@@ -133,6 +132,8 @@ getTotalNodeMem(int nodeId)
 int
 likwid_hwloc_findProcessor(int nodeID, int cpuID)
 {
+    (void)nodeID;
+
     hwloc_obj_t obj;
     int i;
     int pu_count = LIKWID_HWLOC_NAME(get_nbobjs_by_type)(hwloc_topology, HWLOC_OBJ_PU);
@@ -146,7 +147,7 @@ likwid_hwloc_findProcessor(int nodeID, int cpuID)
         }
         else
         {
-            if (obj->os_index == cpuID)
+            if (obj->os_index == (uint32_t)cpuID)
             {
                 return 1;
             }
@@ -162,12 +163,10 @@ hwloc_numa_init(void)
 {
     int errno;
     uint32_t i;
-    int d, j;
+    int j;
     int depth;
-    int cores_per_socket;
     int numPUs = 0;
     hwloc_obj_t obj;
-    const struct hwloc_distances_s* distances;
     struct hwloc_distances_s* dists = NULL;
     unsigned dist_count = 1;
 #if HWLOC_API_VERSION > 0x00020000
@@ -214,7 +213,7 @@ hwloc_numa_init(void)
 #if HWLOC_API_VERSION > 0x00020000
         errno = LIKWID_HWLOC_NAME(distances_get_by_type)(hwloc_topology, hwloc_type, &dist_count, &dists, HWLOC_DISTANCES_KIND_FROM_OS, 0);
 #else
-        distances = LIKWID_HWLOC_NAME(get_whole_distance_matrix_by_type)(hwloc_topology, hwloc_type);
+        const struct hwloc_distances_s* distances = LIKWID_HWLOC_NAME(get_whole_distance_matrix_by_type)(hwloc_topology, hwloc_type);
 #endif
         for (i=0; i<numa_info.numberOfNodes; i++)
         {
@@ -229,7 +228,7 @@ hwloc_numa_init(void)
             else if (obj->attr->numanode.page_types_len != 0)
             {
                 numa_info.nodes[i].totalMemory = 0;
-                for (int k = 0; k < obj->attr->numanode.page_types_len; k++)
+                for (size_t k = 0; k < obj->attr->numanode.page_types_len; k++)
                 {
                     uint64_t size = obj->attr->numanode.page_types[k].size;
                     uint64_t count = obj->attr->numanode.page_types[k].count;
@@ -259,19 +258,18 @@ hwloc_numa_init(void)
                         numPUs * sizeof(uint32_t), i);
                 return -1;
             }
-            d = 0;
             j = 0;
             // call before hwloc update
 
 #if HWLOC_API_VERSION > 0x00020000
-            for (d = 0; d < cpuid_topology.numHWThreads; d++)
+            for (size_t d = 0; d < cpuid_topology.numHWThreads; d++)
             {
                 HWThread *t = &cpuid_topology.threadPool[d];
                 if (LIKWID_HWLOC_NAME(bitmap_isset)(obj->cpuset, t->apicId) && t->threadId == 0)
                 {
                     numa_info.nodes[i].processors[j] = t->apicId;
                     j++;
-                    for (int k = 0; k < cpuid_topology.numHWThreads; k++)
+                    for (size_t k = 0; k < cpuid_topology.numHWThreads; k++)
                     {
                         HWThread *x = &cpuid_topology.threadPool[k];
                         if (t->coreId == x->coreId && t->threadId != x->threadId && LIKWID_HWLOC_NAME(bitmap_isset)(obj->cpuset, x->apicId))
@@ -298,7 +296,7 @@ hwloc_numa_init(void)
             if (dists)
             {
                 int base = LIKWID_HWLOC_NAME(distances_obj_index)(dists, obj);
-                for (d = 0; d < dists->nbobjs; d++)
+                for (size_t d = 0; d < dists->nbobjs; d++)
                 {
                     hwloc_obj_t dobj = dists->objs[d];
                     int idx = LIKWID_HWLOC_NAME(distances_obj_index)(dists, dobj);
@@ -319,7 +317,7 @@ hwloc_numa_init(void)
             else
             {
                 numa_info.nodes[i].numberOfDistances = numa_info.numberOfNodes;
-                for(d = 0; d < numa_info.numberOfNodes; d++)
+                for(size_t d = 0; d < numa_info.numberOfNodes; d++)
                 {
                     numa_info.nodes[i].distances[d] = 10;
                 }
@@ -348,7 +346,7 @@ void
 hwloc_numa_membind(void* ptr, size_t size, int domainId)
 {
     int ret = 0;
-    if (!ptr || size == 0 || domainId < 0 || domainId >= numa_info.numberOfNodes)
+    if (!ptr || size == 0 || domainId < 0 || (uint32_t)domainId >= numa_info.numberOfNodes)
         return;
     hwloc_membind_flags_t flags = HWLOC_MEMBIND_STRICT|HWLOC_MEMBIND_PROCESS|HWLOC_MEMBIND_BYNODESET;
     hwloc_nodeset_t nodeset = LIKWID_HWLOC_NAME(bitmap_alloc)();
@@ -370,14 +368,13 @@ hwloc_numa_membind(void* ptr, size_t size, int domainId)
 void
 hwloc_numa_setInterleaved(int* processorList, int numberOfProcessors)
 {
-    int i,j;
     int ret = 0;
     LIKWID_HWLOC_NAME(cpuset_t) cpuset = LIKWID_HWLOC_NAME(bitmap_alloc)();
     LIKWID_HWLOC_NAME(membind_flags_t) flags = HWLOC_MEMBIND_STRICT|HWLOC_MEMBIND_PROCESS;
     LIKWID_HWLOC_NAME(bitmap_zero)(cpuset);
-    for (i=0; i<numa_info.numberOfNodes; i++)
+    for (size_t i=0; i<numa_info.numberOfNodes; i++)
     {
-        for (j=0; j<numberOfProcessors; j++)
+        for (int j=0; j<numberOfProcessors; j++)
         {
             if (likwid_hwloc_findProcessor(i,processorList[j]))
             {
