@@ -5,13 +5,13 @@
  *
  *      Description:  Interface to hwloc for PCI device lookup
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Author:   Thomas Gruber (tr), thomas.roehl@googlemail.com
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -45,6 +45,7 @@
 #include <dirent.h>
 #include <fcntl.h>
 #include <unistd.h>
+#include <lw_alloc.h>
 
 /* #####   FUNCTION DEFINITIONS  -  EXPORTED FUNCTIONS   ################## */
 
@@ -54,7 +55,6 @@ hwloc_pci_init(uint16_t testDevice, char** socket_bus, int* nrSockets)
     int cntr = 0;
     uint16_t testVendor = 0x8086;
     hwloc_obj_t obj;
-    int flags;
     int i;
 
     if (!hwloc_topology)
@@ -81,8 +81,7 @@ hwloc_pci_init(uint16_t testDevice, char** socket_bus, int* nrSockets)
             while (walk->type != HWLOC_OBJ_SOCKET) walk = walk->parent;
             if (socket_bus[walk->os_index] == NULL)
             {
-                socket_bus[walk->os_index] = (char*)malloc(5);
-                snprintf(socket_bus[walk->os_index], 4, "%02x/", obj->attr->pcidev.bus);
+                socket_bus[walk->os_index] = lw_asprintf("%02x/", obj->attr->pcidev.bus);
                 cntr++;
             }
         }
@@ -101,36 +100,36 @@ hwloc_pci_init(uint16_t testDevice, char** socket_bus, int* nrSockets)
 
 int sysfs_pci_init(uint16_t testDevice, char** socket_bus, int* nrSockets)
 {
+    (void)testDevice;
+
     struct dirent *pDirent, *pDirentInner;
     DIR *pDir, *pDirInner;
     pDir = opendir ("/sys/devices");
-    FILE* fp = NULL;
-    char iPath[200], iiPath[200], buff[100];
-    char testDev[50];
-    size_t ret = 0;
+    char buff[100];
     int nrSocks = 0;
     if (pDir == NULL)
     {
         fprintf(stderr, "Cannot read /sys/devices\n");
         return 1;
     }
+    char* iPath = lw_malloc(1024 * sizeof(char));
+    char* iiPath = lw_malloc(1024 * sizeof(char));
 
     while ((pDirent = readdir(pDir)) != NULL)
     {
-        //printf ("[%s]\n", pDirent->d_name);
+
         if (strncmp(pDirent->d_name, "pci0", 4) == 0)
         {
-            sprintf(iPath, "/sys/devices/%s", pDirent->d_name);
-            char bus[4];
-            strncpy(bus, &(pDirent->d_name[strlen(pDirent->d_name)-2]), 2);
-            bus[2] = '/';
-            bus[3] = '\0';
-            //printf("PATH %s\n", iPath);
-            pDirInner = opendir (iPath);
+            snprintf(iPath, 1024, "/sys/devices/%s", pDirent->d_name);
+
+            size_t bus_index = strlen(pDirent->d_name);
+            if (bus_index >= 2)
+                bus_index -= 2;
+
+            pDirInner = opendir(iPath);
             if (pDir == NULL)
             {
-                fprintf(stderr, "Cannot read %s\n", iPath);
-                return 1;
+                continue;
             }
             while ((pDirentInner = readdir(pDirInner)) != NULL)
             {
@@ -138,28 +137,35 @@ int sysfs_pci_init(uint16_t testDevice, char** socket_bus, int* nrSockets)
                 {
                     uint32_t dev_id = 0x0;
                     int numa_node = 0;
-                    sprintf(iiPath, "/sys/devices/%s/%s/device", pDirent->d_name, pDirentInner->d_name);
-                    fp = fopen(iiPath,"r");
+                    snprintf(iiPath, 1024, "/sys/devices/%s/%s/device", pDirent->d_name, pDirentInner->d_name);
+                    FILE *fp = fopen(iiPath,"r");
                     if( fp == NULL )
                     {
                         continue;
                     }
-                    ret = fread(buff, sizeof(char), 99, fp);
+
+                    if (fgets(buff, sizeof(buff), fp) == NULL) {
+                        fclose(fp);
+                        continue;
+                    }
                     dev_id = strtoul(buff, NULL, 16);
                     if (dev_id == SKYLAKE_SERVER_SOCKETID_MBOX_DID)
                     {
                         fclose(fp);
                         iiPath[0] = '\0';
-                        sprintf(iiPath, "/sys/devices/%s/%s/numa_node", pDirent->d_name, pDirentInner->d_name);
+                        snprintf(iiPath, 1024, "/sys/devices/%s/%s/numa_node", pDirent->d_name, pDirentInner->d_name);
                         fp = fopen(iiPath,"r");
                         if( fp == NULL )
                         {
                             continue;
                         }
-                        ret = fread(buff, sizeof(char), 99, fp);
+                        if (fgets(buff, sizeof(char), fp) == NULL) {
+                            fclose(fp);
+                            continue;
+                        }
                         numa_node = atoi(buff);
-                        socket_bus[numa_node] = (char*)malloc(4);
-                        sprintf(socket_bus[numa_node], "%02x/", bus);
+                        //socket_bus[numa_node] = lw_strndup(bus, 3);
+                        socket_bus[numa_node] = lw_asprintf("%s/", &pDirent->d_name[bus_index]);
                         nrSocks++;
                     }
                     fclose(fp);
@@ -172,6 +178,8 @@ int sysfs_pci_init(uint16_t testDevice, char** socket_bus, int* nrSockets)
         }
     }
     closedir (pDir);
+    free(iPath);
+    free(iiPath);
     *nrSockets = nrSocks;
     return 0;
 }
