@@ -5,14 +5,14 @@
  *
  *      Description:  Interface to control Intel RAPL for the sysFeatures component
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Authors:  Thomas Gruber (tg), thomas.roehl@googlemail.com
  *                Michael Panzlaff, michael.panzlaff@fau.de
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -189,7 +189,7 @@ static int intel_rapl_energy_limit_2_setter(const LikwidDevice_t device, const c
     if (err < 0)
         return err;
     const uint64_t powerUnits = MIN((uint64_t)round(watts / info->powerUnit), 0x7FFF);
-    return likwid_sysft_writemsr_field(device, reg, 15, 15, powerUnits);
+    return likwid_sysft_writemsr_field(device, reg, 32, 15, powerUnits);
 }
 
 static int intel_rapl_energy_limit_2_time_getter(const LikwidDevice_t device, char** value, uint32_t reg, const RaplDomainInfo* info)
@@ -347,6 +347,7 @@ static int intel_rapl_policy_setter(const LikwidDevice_t device, const char* val
 
 static int pkg_test_testFunc(uint64_t msrData, void * value)
 {
+    (void)value;
     if (intel_rapl_pkg_info.powerUnit == 0 && intel_rapl_pkg_info.energyUnit == 0 && intel_rapl_pkg_info.timeUnit == 0)
     {
         intel_rapl_pkg_info.powerUnit = 1.0 / (1 << field64(msrData, 0, 4));
@@ -363,6 +364,7 @@ static int intel_rapl_pkg_test(void)
 
 static int pkg_limit_test_lock_testFunc(uint64_t msrData, void * value)
 {
+    (void)value;
     return field64(msrData, 63, 1);
 }
 
@@ -519,6 +521,7 @@ static const _SysFeatureList intel_rapl_pkg_feature_list = {
 
 static int dram_test_testFunc(uint64_t msrData, void * value)
 {
+    (void)value;
     if (intel_rapl_dram_info.powerUnit == 0 && intel_rapl_dram_info.energyUnit == 0 && intel_rapl_dram_info.timeUnit == 0)
     {
         CpuInfo_t info = get_cpuInfo();
@@ -538,7 +541,7 @@ static int dram_test_testFunc(uint64_t msrData, void * value)
         {
             intel_rapl_dram_info.energyUnit = 15.3e-6;
         }
-        else if (info->model == SAPPHIRERAPIDS)
+        else if (info->model == SAPPHIRERAPIDS || info->model == EMERALDRAPIDS)
         {
             intel_rapl_dram_info.energyUnit = 61e-6;
         }
@@ -566,8 +569,9 @@ static int intel_dram_energy_limit_test(void)
     return likwid_sysft_foreach_socket_testmsr(MSR_DRAM_RAPL_POWER_LIMIT);
 }
 
-static  int dram_limit_test_lock_testFunc(uint64_t msrData, void * value)
+static int dram_limit_test_lock_testFunc(uint64_t msrData, void * value)
 {
+    (void)value;
     return field64(msrData, 31, 1);
 }
 static int intel_rapl_dram_limit_test_lock(void)
@@ -664,12 +668,13 @@ static const _SysFeatureList intel_rapl_dram_feature_list = {
 
 static int psys_test_testFunc(uint64_t msrData, void * value)
 {
+    (void)value;
     if (intel_rapl_psys_info.powerUnit == 0 && intel_rapl_psys_info.energyUnit == 0 && intel_rapl_psys_info.timeUnit == 0)
     {
         CpuInfo_t info = get_cpuInfo();
         intel_rapl_psys_info.powerUnit = 1.0 / (1 << field64(msrData, 0, 4));
         intel_rapl_psys_info.energyUnit = 1.0 / (1 << field64(msrData, 8, 5));
-        if (info->model == SAPPHIRERAPIDS)
+        if (info->model == SAPPHIRERAPIDS || info->model == EMERALDRAPIDS)
         {
             intel_rapl_psys_info.energyUnit = 1.0;
         }
@@ -700,6 +705,7 @@ static int intel_psys_energy_limit_test(void)
 
 static int psys_limit_test_lock_testFunc(uint64_t msrData, void * value)
 {
+    (void)value;
     return field64(msrData, 63, 1);
 }
 
@@ -812,6 +818,7 @@ static const _SysFeatureList intel_rapl_psys_feature_list = {
 
 static int pp0_test_testFunc(uint64_t msrData, void * value)
 {
+    (void)value;
     if (intel_rapl_pp0_info.powerUnit == 0 && intel_rapl_pp0_info.energyUnit == 0 && intel_rapl_pp0_info.timeUnit == 0)
     {
         intel_rapl_pp0_info.powerUnit = 1.0 / (1 << field64(msrData, 0, 4));
@@ -843,6 +850,7 @@ static int intel_pp0_energy_limit_test(void)
 
 static int pp0_limit_test_lock_testFunc(uint64_t msrData, void * value)
 {
+    (void)value;
     return field64(msrData, 31, 1);
 }
 
@@ -912,7 +920,7 @@ static _SysFeature intel_rapl_pp0_features[] = {
     {"pp0_limit_time", "rapl", "Long-term time window (PP0 domain)", intel_pp0_energy_limit_1_time_getter, intel_pp0_energy_limit_1_time_setter, DEVICE_TYPE_SOCKET, intel_pp0_energy_limit_test, "s"},
     {"pp0_limit_enable", "rapl", "Status of long-term energy limit (PP0 domain)", intel_pp0_energy_limit_1_enable_getter, intel_pp0_energy_limit_1_enable_setter, DEVICE_TYPE_SOCKET, intel_pp0_energy_limit_test, "bool"},
     {"pp0_limit_clamp", "rapl", "Clamping status of long-term energy limit (PP0 domain)", intel_pp0_energy_limit_1_clamp_getter, intel_pp0_energy_limit_1_clamp_setter, DEVICE_TYPE_SOCKET, intel_pp0_energy_limit_test, "bool"},
-    {"pp0_policy", "rapl", "Balance Power Policy (PP0 domain)", intel_pp0_policy_getter, intel_pp0_policy_setter, DEVICE_TYPE_SOCKET, intel_pp0_policy_test},
+    {"pp0_policy", "rapl", "Balance Power Policy (PP0 domain)", intel_pp0_policy_getter, intel_pp0_policy_setter, DEVICE_TYPE_SOCKET, intel_pp0_policy_test, NULL},
 };
 
 static const _SysFeatureList intel_rapl_pp0_feature_list = {
@@ -927,6 +935,7 @@ static const _SysFeatureList intel_rapl_pp0_feature_list = {
 
 static int pp1_test_testFunc(uint64_t msrData, void * value)
 {
+    (void)value;
     if (intel_rapl_pp1_info.powerUnit == 0 && intel_rapl_pp1_info.energyUnit == 0 && intel_rapl_pp1_info.timeUnit == 0)
     {
         intel_rapl_pp1_info.powerUnit = 1.0 / (1 << field64(msrData, 0, 4));
@@ -958,6 +967,7 @@ static int intel_pp1_energy_limit_test(void)
 
 static int pp1_limit_test_lock(uint64_t msrData, void * value)
 {
+    (void)value;
     return field64(msrData, 31, 1);
 }
 
@@ -1041,12 +1051,26 @@ static const _SysFeatureList intel_rapl_pp1_feature_list = {
 int likwid_sysft_init_intel_rapl(_SysFeatureList* out)
 {
     int err = 0;
+    Configuration_t config = NULL;
+    err = init_configuration();
+    if (err < 0)
+    {
+        errno = -err;
+        ERROR_PRINT("Failed to initialize configuration");
+        return err;
+    }
+    config = get_configuration();
+    if (config->daemonMode == ACCESSMODE_PERF)
+    {
+        DEBUG_PRINT(DEBUGLEV_INFO, "No Intel RAPL support with accessmode=perf_event");
+        return 0;
+    }
     if (intel_rapl_pkg_test())
     {
-        DEBUG_PRINT(DEBUGLEV_INFO, Register Intel RAPL PKG domain);
+        DEBUG_PRINT(DEBUGLEV_INFO, "Register Intel RAPL PKG domain");
         if (intel_rapl_pkg_limit_test_lock() > 0)
         {
-            DEBUG_PRINT(DEBUGLEV_INFO, Intel RAPL PKG domain locked);
+            DEBUG_PRINT(DEBUGLEV_INFO, "Intel RAPL PKG domain locked");
             for (int i = 0; i < intel_rapl_pkg_feature_list.num_features; i++)
             {
                 intel_rapl_pkg_feature_list.features[i].setter = NULL;
@@ -1055,19 +1079,19 @@ int likwid_sysft_init_intel_rapl(_SysFeatureList* out)
         err = likwid_sysft_register_features(out, &intel_rapl_pkg_feature_list);
         if (err < 0)
         {
-            DEBUG_PRINT(DEBUGLEV_INFO, RAPL domain PKG not supported);
+            DEBUG_PRINT(DEBUGLEV_INFO, "Intel RAPL domain PKG not supported");
         }
     }
     else
     {
-        DEBUG_PRINT(DEBUGLEV_INFO, RAPL domain PKG not supported);
+        DEBUG_PRINT(DEBUGLEV_INFO, "Intel RAPL domain PKG not supported");
     }
     if (intel_rapl_dram_test())
     {
-        DEBUG_PRINT(DEBUGLEV_INFO, Register Intel RAPL DRAM domain);
+        DEBUG_PRINT(DEBUGLEV_INFO, "Register Intel RAPL DRAM domain");
         if (intel_rapl_dram_limit_test_lock() > 0)
         {
-            DEBUG_PRINT(DEBUGLEV_INFO, Intel RAPL DRAM domain locked);
+            DEBUG_PRINT(DEBUGLEV_INFO, "Intel RAPL DRAM domain locked");
             for (int i = 0; i < intel_rapl_dram_feature_list.num_features; i++)
             {
                 intel_rapl_dram_feature_list.features[i].setter = NULL;
@@ -1076,19 +1100,19 @@ int likwid_sysft_init_intel_rapl(_SysFeatureList* out)
         err = likwid_sysft_register_features(out, &intel_rapl_dram_feature_list);
         if (err < 0)
         {
-            DEBUG_PRINT(DEBUGLEV_INFO, RAPL domain DRAM not supported);
+            DEBUG_PRINT(DEBUGLEV_INFO, "Intel RAPL domain DRAM not supported");
         }
     }
     else
     {
-        DEBUG_PRINT(DEBUGLEV_INFO, RAPL domain DRAM not supported);
+        DEBUG_PRINT(DEBUGLEV_INFO, "Intel RAPL domain DRAM not supported");
     }
     if (intel_rapl_pp0_test())
     {
-        DEBUG_PRINT(DEBUGLEV_INFO, Register Intel RAPL PP0 domain);
+        DEBUG_PRINT(DEBUGLEV_INFO, "Register Intel RAPL PP0 domain");
         if (intel_rapl_pp0_limit_test_lock() > 0)
         {
-            DEBUG_PRINT(DEBUGLEV_INFO, Intel RAPL PP0 domain locked);
+            DEBUG_PRINT(DEBUGLEV_INFO, "Intel RAPL PP0 domain locked");
             for (int i = 0; i < intel_rapl_pp0_feature_list.num_features; i++)
             {
                 intel_rapl_pp0_feature_list.features[i].setter = NULL;
@@ -1097,19 +1121,19 @@ int likwid_sysft_init_intel_rapl(_SysFeatureList* out)
         err = likwid_sysft_register_features(out, &intel_rapl_pp0_feature_list);
         if (err < 0)
         {
-            DEBUG_PRINT(DEBUGLEV_INFO, RAPL domain PP0 not supported);
+            DEBUG_PRINT(DEBUGLEV_INFO, "Intel RAPL domain PP0 not supported");
         }
     }
     else
     {
-        DEBUG_PRINT(DEBUGLEV_INFO, RAPL domain PP0 not supported);
+        DEBUG_PRINT(DEBUGLEV_INFO, "Intel RAPL domain PP0 not supported");
     }
     if (intel_rapl_pp1_test())
     {
-        DEBUG_PRINT(DEBUGLEV_INFO, Register Intel RAPL PP1 domain);
+        DEBUG_PRINT(DEBUGLEV_INFO, "Register Intel RAPL PP1 domain");
         if (intel_rapl_pp1_limit_test_lock() > 0)
         {
-            DEBUG_PRINT(DEBUGLEV_INFO, Intel RAPL PP1 domain locked);
+            DEBUG_PRINT(DEBUGLEV_INFO, "Intel RAPL PP1 domain locked");
             for (int i = 0; i < intel_rapl_pp1_feature_list.num_features; i++)
             {
                 intel_rapl_pp1_feature_list.features[i].setter = NULL;
@@ -1118,19 +1142,19 @@ int likwid_sysft_init_intel_rapl(_SysFeatureList* out)
         err = likwid_sysft_register_features(out, &intel_rapl_pp1_feature_list);
         if (err < 0)
         {
-            DEBUG_PRINT(DEBUGLEV_INFO, RAPL domain PP1 not supported);
+            DEBUG_PRINT(DEBUGLEV_INFO, "Intel RAPL domain PP1 not supported");
         }
     }
     else
     {
-        DEBUG_PRINT(DEBUGLEV_INFO, RAPL domain PP1 not supported);
+        DEBUG_PRINT(DEBUGLEV_INFO, "Intel RAPL domain PP1 not supported");
     }
     if (intel_rapl_psys_test())
     {
-        DEBUG_PRINT(DEBUGLEV_INFO, Register Intel RAPL PSYS domain);
+        DEBUG_PRINT(DEBUGLEV_INFO, "Register Intel RAPL PSYS domain");
         if (intel_rapl_psys_limit_test_lock() > 0)
         {
-            DEBUG_PRINT(DEBUGLEV_INFO, Intel RAPL PSYS domain locked);
+            DEBUG_PRINT(DEBUGLEV_INFO, "Intel RAPL PSYS domain locked");
             for (int i = 0; i < intel_rapl_psys_feature_list.num_features; i++)
             {
                 intel_rapl_psys_feature_list.features[i].setter = NULL;
@@ -1139,12 +1163,12 @@ int likwid_sysft_init_intel_rapl(_SysFeatureList* out)
         err = likwid_sysft_register_features(out, &intel_rapl_psys_feature_list);
         if (err < 0)
         {
-            DEBUG_PRINT(DEBUGLEV_INFO, RAPL domain PSYS not supported);
+            DEBUG_PRINT(DEBUGLEV_INFO, "Intel RAPL domain PSYS not supported");
         }
     }
     else
     {
-        DEBUG_PRINT(DEBUGLEV_INFO, RAPL domain PSYS not supported);
+        DEBUG_PRINT(DEBUGLEV_INFO, "Intel RAPL domain PSYS not supported");
     }
     return 0;
 }
