@@ -5,13 +5,13 @@
  *
  *      Description:  Interface to control various Nvidia NVML based features
  *
- *      Version:   5.4.0
- *      Released:  15.11.2024
+ *      Version:   <VERSION>
+ *      Released:  <DATE>
  *
  *      Authors:  Michael Panzlaff, michael.panzlaff@fau.de
  *      Project:  likwid
  *
- *      Copyright (C) 2024 RRZE, University Erlangen-Nuremberg
+ *      Copyright (C) 2016 RRZE, University Erlangen-Nuremberg
  *
  *      This program is free software: you can redistribute it and/or modify it under
  *      the terms of the GNU General Public License as published by the Free Software
@@ -33,6 +33,8 @@
 #include <math.h>
 #include <dlfcn.h>
 #include <nvml.h>
+#include <cuda.h>
+#include <cuda_runtime_api.h>
 #include <limits.h>
 #include <stdbool.h>
 #include <stdlib.h>
@@ -48,16 +50,16 @@
     do {                                                                \
         const char *err = dlerror();                                    \
         if (err) {                                                      \
-            ERROR_PRINT(Error: dlsym on symbol '%s' failed with error: %s, #name, err); \
+            ERROR_PRINT("Error: dlsym on symbol '%s' failed with error: %s", #name, err); \
             return -EINVAL;                                             \
         }                                                               \
     } while (0)
 
 #define NVML_CALL(func, ...)                            \
     do {                                                \
-        nvmlReturn_t s = (*func##_ptr)(__VA_ARGS__);    \
-        if (s != NVML_SUCCESS) {                        \
-            ERROR_PRINT(Error: function %s failed with error: '%s' (nvmlReturn=%d).\n, #func, nvmlErrorString_ptr(s), s);   \
+        nvmlReturn_t s_ = (*func##_ptr)(__VA_ARGS__);    \
+        if (s_ != NVML_SUCCESS) {                        \
+            ERROR_PRINT("Error: function %s failed with error: '%s' (nvmlReturn=%d).", #func, nvmlErrorString_ptr(s_), s_);   \
             return -EPERM;                              \
         }                                               \
     } while (0)
@@ -72,7 +74,6 @@
     } while (0)
 
 DECLAREFUNC_NVML(nvmlDeviceGetBAR1MemoryInfo, nvmlDevice_t device, nvmlBAR1Memory_t* bar1Memory);
-DECLAREFUNC_NVML(nvmlDeviceGetBusType, nvmlDevice_t device, nvmlBusType_t *type);
 DECLAREFUNC_NVML(nvmlDeviceGetClock, nvmlDevice_t device, nvmlClockType_t clockType, nvmlClockId_t clockId, unsigned int* clockMHz);
 DECLAREFUNC_NVML(nvmlDeviceGetClockInfo, nvmlDevice_t device, nvmlClockType_t type, unsigned int* clock);
 DECLAREFUNC_NVML(nvmlDeviceGetCurrPcieLinkGeneration, nvmlDevice_t device, unsigned int *currLinkGen);
@@ -123,6 +124,14 @@ static const char *(*nvmlErrorString_ptr)(nvmlReturn_t result);
 DECLAREFUNC_NVML(nvmlInit_v2, void);
 DECLAREFUNC_NVML(nvmlShutdown, void);
 
+#if defined(CUDART_VERSION) && CUDART_VERSION < 11060
+typedef unsigned int nvmlBusType_t;
+#define NVML_BUS_TYPE_UNKNOWN  0
+#else
+DECLAREFUNC_NVML(nvmlDeviceGetBusType, nvmlDevice_t device, nvmlBusType_t *type);
+#endif
+
+
 static const _SysFeatureList nvidia_gpu_feature_list;
 static bool nvml_initialized = false;
 static void *dl_nvml = NULL;
@@ -142,14 +151,19 @@ int likwid_sysft_init_nvml(_SysFeatureList *list)
         return 0;
 
     dl_nvml = dlopen("libnvidia-ml.so", RTLD_NOW | RTLD_GLOBAL);
+    if (!dl_nvml)
+        dl_nvml = dlopen("libnvidia-ml.so.1", RTLD_NOW | RTLD_GLOBAL);
+
     if (!dl_nvml)
     {
-        ERROR_PRINT(dlopen(libnvidia-ml.so) failed: %s, dlerror());
+        DEBUG_PRINT(DEBUGLEV_INFO, "dlopen(libnvidia-ml.so) failed: %s", dlerror());
         return -ELIBACC;
     }
 
     DLSYM_AND_CHECK(dl_nvml, nvmlDeviceGetBAR1MemoryInfo);
+#if defined(CUDART_VERSION) && CUDART_VERSION >= 11060
     DLSYM_AND_CHECK(dl_nvml, nvmlDeviceGetBusType);
+#endif
     DLSYM_AND_CHECK(dl_nvml, nvmlDeviceGetClock);
     DLSYM_AND_CHECK(dl_nvml, nvmlDeviceGetClockInfo);
     DLSYM_AND_CHECK(dl_nvml, nvmlDeviceGetCurrPcieLinkGeneration);
@@ -203,7 +217,7 @@ int likwid_sysft_init_nvml(_SysFeatureList *list)
     if (nverr != NVML_SUCCESS)
     {
         dlclose(dl_nvml);
-        ERROR_PRINT(nvmlInit_v2() failed: %s, nvmlErrorString_ptr(nverr));
+        ERROR_PRINT("nvmlInit_v2() failed: %s", nvmlErrorString_ptr(nverr));
         return -EPERM;
     }
 
@@ -391,8 +405,10 @@ static int nvidia_gpu_bar1_total_getter(const LikwidDevice_t device, char **valu
 static int nvidia_gpu_bus_type_getter(const LikwidDevice_t device, char **value)
 {
     LWD_TO_NVMLD(device, nvmlDevice);
-    nvmlBusType_t type;
+    nvmlBusType_t type = NVML_BUS_TYPE_UNKNOWN;
+#if defined(CUDART_VERSION) && CUDART_VERSION >= 11060
     NVML_CALL(nvmlDeviceGetBusType, nvmlDevice, &type);
+#endif
     static const char *types[] = {
         "Unknown", "PCI", "PCIe", "FPCI", "AGP",
     };
@@ -754,10 +770,12 @@ static int nvidia_gpu_encoder_capacity_hevc_getter(const LikwidDevice_t device,
     return nvidia_gpu_encoder_capacity_getter(device, NVML_ENCODER_QUERY_HEVC, value);
 }
 
+#if defined(CUDART_VERSION) && CUDART_VERSION >= 12030
 static int nvidia_gpu_encoder_capacity_av1_getter(const LikwidDevice_t device, char **value)
 {
     return nvidia_gpu_encoder_capacity_getter(device, NVML_ENCODER_QUERY_AV1, value);
 }
+#endif
 
 static int nvidia_gpu_encoder_usage_getter(const LikwidDevice_t device, char **value)
 {
@@ -866,6 +884,7 @@ static int nvidia_gpu_temp_thresh_gpu_max_getter(const LikwidDevice_t device, ch
     return nvidia_gpu_temp_thresh_getter(device, NVML_TEMPERATURE_THRESHOLD_GPU_MAX, value);
 }
 
+#if defined(CUDART_VERSION) && CUDART_VERSION >= 11020
 static int nvidia_gpu_temp_thresh_acou_min_getter(const LikwidDevice_t device, char **value)
 {
     return nvidia_gpu_temp_thresh_getter(device, NVML_TEMPERATURE_THRESHOLD_ACOUSTIC_MIN, value);
@@ -880,11 +899,14 @@ static int nvidia_gpu_temp_thresh_acou_max_getter(const LikwidDevice_t device, c
 {
     return nvidia_gpu_temp_thresh_getter(device, NVML_TEMPERATURE_THRESHOLD_ACOUSTIC_MAX, value);
 }
+#endif
 
+#if defined(CUDART_VERSION) && CUDART_VERSION >= 12060
 static int nvidia_gpu_temp_thresh_gps_cur_getter(const LikwidDevice_t device, char **value)
 {
     return nvidia_gpu_temp_thresh_getter(device, NVML_TEMPERATURE_THRESHOLD_GPS_CURR, value);
 }
+#endif
 
 static int nvidia_gpu_temp_thresh_setter(const LikwidDevice_t device, nvmlTemperatureThresholds_t t, const char *value)
 {
@@ -920,6 +942,7 @@ static int nvidia_gpu_temp_thresh_gpu_max_setter(const LikwidDevice_t device, co
     return nvidia_gpu_temp_thresh_setter(device, NVML_TEMPERATURE_THRESHOLD_GPU_MAX, value);
 }
 
+#if defined(CUDART_VERSION) && CUDART_VERSION >= 11020
 static int nvidia_gpu_temp_thresh_acou_min_setter(const LikwidDevice_t device, const char *value)
 {
     return nvidia_gpu_temp_thresh_setter(device, NVML_TEMPERATURE_THRESHOLD_ACOUSTIC_MIN, value);
@@ -934,11 +957,14 @@ static int nvidia_gpu_temp_thresh_acou_max_setter(const LikwidDevice_t device, c
 {
     return nvidia_gpu_temp_thresh_setter(device, NVML_TEMPERATURE_THRESHOLD_ACOUSTIC_MAX, value);
 }
+#endif
 
+#if defined(CUDART_VERSION) && CUDART_VERSION >= 12060
 static int nvidia_gpu_temp_thresh_gps_cur_setter(const LikwidDevice_t device, const char *value)
 {
     return nvidia_gpu_temp_thresh_setter(device, NVML_TEMPERATURE_THRESHOLD_GPS_CURR, value);
 }
+#endif
 
 static int nvidia_gpu_ofa_usage_getter(const LikwidDevice_t device, char **value)
 {
@@ -1025,8 +1051,8 @@ static int nvidia_gpu_policy_time_total_base_getter(const LikwidDevice_t device,
 }
 
 static _SysFeature nvidia_gpu_features[] = {
-    {"device_count", "nvml", "Number of GPUs on node. Not all GPUs may be accessible.", nvidia_gpu_device_count_getter, NULL, DEVICE_TYPE_NODE},
-    {"devices_available", "nvml", "Available GPUs (PCI addresses)", nvidia_gpu_devices_available_getter, NULL, DEVICE_TYPE_NODE},
+    {"device_count", "nvml", "Number of GPUs on node. Not all GPUs may be accessible.", nvidia_gpu_device_count_getter, NULL, DEVICE_TYPE_NODE, NULL, NULL},
+    {"devices_available", "nvml", "Available GPUs (PCI addresses)", nvidia_gpu_devices_available_getter, NULL, DEVICE_TYPE_NODE, NULL, NULL},
     {"gfx_clock_cur", "nvml", "Current clock speed (graphics domain)", nvidia_gpu_gfx_clock_cur_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "MHz"},
     {"gfx_clock_app_target", "nvml", "Application target clock speed (graphics domain)", nvidia_gpu_gfx_clock_app_target_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "MHz"},
     {"gfx_clock_app_default", "nvml", "Application default clock speed (graphics domain)", nvidia_gpu_gfx_clock_app_default_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "MHz"},
@@ -1046,39 +1072,39 @@ static _SysFeature nvidia_gpu_features[] = {
     {"pci_bar1_free", "nvml", "Unallocated BAR1 memory", nvidia_gpu_bar1_free_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "Byte"},
     {"pci_bar1_used", "nvml", "Allocated BAR1 memory", nvidia_gpu_bar1_used_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "Byte"},
     {"pci_bar1_total", "nvml", "Total BAR1 memory", nvidia_gpu_bar1_total_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "Byte"},
-    {"bus_type", "nvml", "GPU Bus Type", nvidia_gpu_bus_type_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"pcie_link_gen_cur", "nvml", "Current PCIe link generation", nvidia_gpu_pcie_gen_cur_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"pcie_link_gen_gpu_max", "nvml", "Maximum PCIe link generation (GPU only)", nvidia_gpu_pcie_gen_gpu_max_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"pcie_link_gen_sys_max", "nvml", "Maximum PCIe link generation (GPU/system combination)", nvidia_gpu_pcie_gen_sys_max_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"pcie_link_width_cur", "nvml", "Current PCIe link width (GPU only)", nvidia_gpu_pcie_width_cur_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"pcie_link_width_sys_max", "nvml", "Maximum PCIe link width (CPU/system combination)", nvidia_gpu_pcie_width_sys_max_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
+    {"bus_type", "nvml", "GPU Bus Type", nvidia_gpu_bus_type_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"pcie_link_gen_cur", "nvml", "Current PCIe link generation", nvidia_gpu_pcie_gen_cur_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"pcie_link_gen_gpu_max", "nvml", "Maximum PCIe link generation (GPU only)", nvidia_gpu_pcie_gen_gpu_max_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"pcie_link_gen_sys_max", "nvml", "Maximum PCIe link generation (GPU/system combination)", nvidia_gpu_pcie_gen_sys_max_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"pcie_link_width_cur", "nvml", "Current PCIe link width (GPU only)", nvidia_gpu_pcie_width_cur_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"pcie_link_width_sys_max", "nvml", "Maximum PCIe link width (CPU/system combination)", nvidia_gpu_pcie_width_sys_max_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
     {"pcie_link_rate_cur", "nvml", "Current PCIe link speed", nvidia_gpu_pcie_speed_cur_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "MB/s"},
     {"pcie_link_rate_max", "nvml", "Maximum PCIe link speed", nvidia_gpu_pcie_speed_max_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "MB/s"},
-    {"pcie_replay_counter", "nvml", "PCIe replay counter", nvidia_gpu_pcie_replay_counter_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
+    {"pcie_replay_counter", "nvml", "PCIe replay counter", nvidia_gpu_pcie_replay_counter_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
     {"pcie_throughput_tx", "nvml", "Current PCIe throughput (TX)", nvidia_gpu_pcie_throughput_tx_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "KB/s"},
     {"pcie_throughput_rx", "nvml", "Current PCIe throughput (RX)", nvidia_gpu_pcie_throughput_rx_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "KB/s"},
-    {"decoder_usage", "nvml", "Current decoder usage", nvidia_gpu_decoder_util_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_enabled_default", "nvml", "DRAM ECC enable default", nvidia_gpu_ecc_default_enabled_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_enabled_cur", "nvml", "DRAM ECC currently enabled", nvidia_gpu_ecc_enabled_cur_getter, nvidia_gpu_ecc_enabled_setter, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_enabled_pend", "nvml", "DRAM ECC enable pending (after reboot)", nvidia_gpu_ecc_enabled_pend_getter, nvidia_gpu_ecc_enabled_setter, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_dram_volatile_corr_err_count", "nvml", "DRAM ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_dram_vol_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_dram_volatile_uncorr_err_count", "nvml", "DRAM ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_dram_vol_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_dram_aggregate_corr_err_count", "nvml", "DRAM ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_dram_agg_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_dram_aggregate_uncorr_err_count", "nvml", "DRAM ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_dram_agg_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_l1_volatile_corr_err_count", "nvml", "L1 ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_l1_vol_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_l1_volatile_uncorr_err_count", "nvml", "L1 ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_l1_vol_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_l1_aggregate_corr_err_count", "nvml", "L1 ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_l1_agg_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_l1_aggregate_uncorr_err_count", "nvml", "L1 ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_l1_agg_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_l2_volatile_corr_err_count", "nvml", "L2 ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_l2_vol_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_l2_volatile_uncorr_err_count", "nvml", "L2 ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_l2_vol_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_l2_aggregate_corr_err_count", "nvml", "L2 ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_l2_agg_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_l2_aggregate_uncorr_err_count", "nvml", "L2 ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_l2_agg_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_reg_volatile_corr_err_count", "nvml", "REG ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_reg_vol_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_reg_volatile_uncorr_err_count", "nvml", "REG ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_reg_vol_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_reg_aggregate_corr_err_count", "nvml", "REG ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_reg_agg_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"ecc_reg_aggregate_uncorr_err_count", "nvml", "REG ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_reg_agg_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
+    {"decoder_usage", "nvml", "Current decoder usage", nvidia_gpu_decoder_util_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_enabled_default", "nvml", "DRAM ECC enable default", nvidia_gpu_ecc_default_enabled_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_enabled_cur", "nvml", "DRAM ECC currently enabled", nvidia_gpu_ecc_enabled_cur_getter, nvidia_gpu_ecc_enabled_setter, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_enabled_pend", "nvml", "DRAM ECC enable pending (after reboot)", nvidia_gpu_ecc_enabled_pend_getter, nvidia_gpu_ecc_enabled_setter, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_dram_volatile_corr_err_count", "nvml", "DRAM ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_dram_vol_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_dram_volatile_uncorr_err_count", "nvml", "DRAM ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_dram_vol_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_dram_aggregate_corr_err_count", "nvml", "DRAM ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_dram_agg_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_dram_aggregate_uncorr_err_count", "nvml", "DRAM ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_dram_agg_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_l1_volatile_corr_err_count", "nvml", "L1 ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_l1_vol_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_l1_volatile_uncorr_err_count", "nvml", "L1 ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_l1_vol_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_l1_aggregate_corr_err_count", "nvml", "L1 ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_l1_agg_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_l1_aggregate_uncorr_err_count", "nvml", "L1 ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_l1_agg_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_l2_volatile_corr_err_count", "nvml", "L2 ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_l2_vol_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_l2_volatile_uncorr_err_count", "nvml", "L2 ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_l2_vol_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_l2_aggregate_corr_err_count", "nvml", "L2 ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_l2_agg_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_l2_aggregate_uncorr_err_count", "nvml", "L2 ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_l2_agg_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_reg_volatile_corr_err_count", "nvml", "REG ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_reg_vol_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_reg_volatile_uncorr_err_count", "nvml", "REG ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_reg_vol_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_reg_aggregate_corr_err_count", "nvml", "REG ECC corrected errors (GPU lifetime aggregate)", nvidia_gpu_ecc_error_reg_agg_corr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"ecc_reg_aggregate_uncorr_err_count", "nvml", "REG ECC corrected errors (since reboot)", nvidia_gpu_ecc_error_reg_agg_uncorr_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
     {"fan_speed", "nvml", "Fan speed", nvidia_gpu_fan_speed_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "%"},
-    {"pstate_cur", "nvml", "Current performance state", nvidia_gpu_pstate_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL},
+    {"pstate_cur", "nvml", "Current performance state", nvidia_gpu_pstate_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
     {"power_limit_default", "nvml", "Default power limit", nvidia_gpu_power_limit_default_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "W"},
     {"power_limit_cur", "nvml", "Current power limit", nvidia_gpu_power_limit_cur_getter, nvidia_gpu_power_limit_cur_setter, DEVICE_TYPE_NVIDIA_GPU, NULL, "W"},
     {"power_limit_min", "nvml", "Minimum power limit", nvidia_gpu_power_limit_min_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "W"},
@@ -1087,10 +1113,12 @@ static _SysFeature nvidia_gpu_features[] = {
     {"power_usage", "nvml", "Current power usage", nvidia_gpu_power_cur_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "W"},
     {"encoder_cap_h264", "nvml", "Video encoder H264 capacity", nvidia_gpu_encoder_capacity_h264_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "%"},
     {"encoder_cap_hevc", "nvml", "Video encoder HEVC capacity", nvidia_gpu_encoder_capacity_hevc_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "%"},
+#if defined(CUDART_VERSION) && CUDART_VERSION >= 12030
     {"encoder_cap_av1", "nvml", "Video encoder AV1 capacity", nvidia_gpu_encoder_capacity_av1_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "%"},
+#endif
     {"encoder_usage", "nvml", "Video encoder usage", nvidia_gpu_encoder_usage_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "%"},
-    {"gom_cur", "nvml", "Current GPU operation mode (all_on, compute_only, graphics_only)", nvidia_gpu_gom_cur_getter, nvidia_gpu_gom_setter, DEVICE_TYPE_NVIDIA_GPU, NULL},
-    {"gom_pend", "nvml", "Pending (after reboot) GPU operation mode (all_on, compute_only, graphics_only)", nvidia_gpu_gom_pend_getter, nvidia_gpu_gom_setter, DEVICE_TYPE_NVIDIA_GPU, NULL},
+    {"gom_cur", "nvml", "Current GPU operation mode (all_on, compute_only, graphics_only)", nvidia_gpu_gom_cur_getter, nvidia_gpu_gom_setter, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
+    {"gom_pend", "nvml", "Pending (after reboot) GPU operation mode (all_on, compute_only, graphics_only)", nvidia_gpu_gom_pend_getter, nvidia_gpu_gom_setter, DEVICE_TYPE_NVIDIA_GPU, NULL, NULL},
     {"jpg_usage", "nvml", "JPG usage", nvidia_gpu_jpg_usage_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "%"},
     {"dram_bus_width", "nvml", "DRAM bus width", nvidia_gpu_dram_bus_width_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "Bit"},
     {"multi_gpu", "nvml", "Multi GPU board", nvidia_gpu_multi_gpu_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "bool"},
@@ -1099,10 +1127,14 @@ static _SysFeature nvidia_gpu_features[] = {
     {"temp_thresh_slow", "nvml", "Slowdown Temperature threshold", nvidia_gpu_temp_thresh_slow_getter, nvidia_gpu_temp_thresh_slow_setter, DEVICE_TYPE_NVIDIA_GPU, NULL, "degrees C"},
     {"temp_thresh_mem_max", "nvml", "Maximum memory temperature threshold", nvidia_gpu_temp_thresh_mem_max_getter, nvidia_gpu_temp_thresh_mem_max_setter, DEVICE_TYPE_NVIDIA_GPU, NULL, "degrees C"},
     {"temp_thresh_gpu_max", "nvml", "Maximum GPU temperature threshold", nvidia_gpu_temp_thresh_gpu_max_getter, nvidia_gpu_temp_thresh_gpu_max_setter, DEVICE_TYPE_NVIDIA_GPU, NULL, "degrees C"},
+#if defined(CUDART_VERSION) && CUDART_VERSION >= 11020
     {"temp_thresh_acou_min", "nvml", "Minimum acoustic temperature threshold", nvidia_gpu_temp_thresh_acou_min_getter, nvidia_gpu_temp_thresh_acou_min_setter, DEVICE_TYPE_NVIDIA_GPU, NULL, "degrees C"},
     {"temp_thresh_acou_cur", "nvml", "Current acoustic temperature threshold", nvidia_gpu_temp_thresh_acou_cur_getter, nvidia_gpu_temp_thresh_acou_cur_setter, DEVICE_TYPE_NVIDIA_GPU, NULL, "degrees C"},
     {"temp_thresh_acou_max", "nvml", "Maximum acoustic temperature threshold", nvidia_gpu_temp_thresh_acou_max_getter, nvidia_gpu_temp_thresh_acou_max_setter, DEVICE_TYPE_NVIDIA_GPU, NULL, "degrees C"},
+#endif
+#if defined(CUDART_VERSION) && CUDART_VERSION >= 12060
     {"temp_thresh_gps_cur", "nvml", "Current GPS temperature threshold", nvidia_gpu_temp_thresh_gps_cur_getter, nvidia_gpu_temp_thresh_gps_cur_setter, DEVICE_TYPE_NVIDIA_GPU, NULL, "degrees C"},
+#endif
     {"ofa_usage", "nvml", "Optical Flow Accelerator usage", nvidia_gpu_ofa_usage_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "%"},
     {"energy", "nvml", "Energy consumed since driver reload", nvidia_gpu_energy_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "J"},
     {"gpu_usage", "nvml", "GPU usage", nvidia_gpu_gpu_usage_getter, NULL, DEVICE_TYPE_NVIDIA_GPU, NULL, "%"},
